@@ -54,10 +54,10 @@
 #include <string>
 #include "icalmapi.h"
 
-bool ICALMAPI_API IsOutlookUid(std::string strUid);
+bool ICALMAPI_API IsOutlookUid(const std::string &strUid);
 HRESULT ICALMAPI_API HrGenerateUid(std::string *lpStrUid);
 HRESULT ICALMAPI_API HrCreateGlobalID(ULONG ulNamedTag, void *base, LPSPropValue *lppPropVal);
 HRESULT ICALMAPI_API HrGetICalUidFromBinUid(SBinary &sBin, std::string *lpStrUid);
-HRESULT ICALMAPI_API HrMakeBinUidFromICalUid(std::string strUid, std::string *lpStrBinUid);
+HRESULT ICALMAPI_API HrMakeBinUidFromICalUid(const std::string &strUid, std::string *lpStrBinUid);
 
 #endif
