@@ -50,30 +50,12 @@
 #ifndef ICALMAPI_VFREEBUSY_H
 #define ICALMAPI_VFREEBUSY_H
 
-#include "vconverter.h"
 #include "freebusy.h"
+#include <libical/ical.h>
+#include <list>
+#include <string>
 
-class VFreebusyConverter : public VConverter {
-public:
-	/* lpNamedProps must be the GetIDsFromNames() of the array in nameids.h */
-	VFreebusyConverter(LPADRBOOK lpAdrBook, timezone_map *mapTimeZones, LPSPropTagArray lpNamedProps, ECIConv *lpIConv, bool blCensor, bool bNoRecipients, IMailUser *lpImailUser);
-	virtual ~VFreebusyConverter();
-
-	HRESULT HrICal2MAPI(icalcomponent *lpEventRoot /* in */, icalcomponent *lpEvent /* in */, icalitem *lpPrevItem /* in */, icalitem **lppRet /* out */);
-	HRESULT HrGetFbInfo(icalcomponent *lpFbical, time_t *tStart, time_t *tEnd, std::string *lpstrUID, std::list<std::string> *lstUsers);
-	HRESULT HrFbBlock2ical(FBBlock_1 *lpsFbblk, LONG ulblocks, time_t tStart, time_t tEnd, std::string strOrganiser, std::string strUser, std::string strUID, icalcomponent **lpicFbComponent);
-	
-
-private:
-	/* overrides, ical -> mapi */
-	HRESULT HrAddMessageClass(icalproperty_method icMethod, icalcomponent *lpicEvent, icalitem *lpIcalItem, bool bIsException, std::list<SPropValue> *lstMsgProps);
-	HRESULT HrAddTimes(icalcomponent *lpicEventRoot, icalcomponent *lpicEvent, icalitem *lpIcalItem);
-
-	/* overrides, mapi -> ical */
-	HRESULT HrMAPI2ICal(LPMESSAGE lpMessage, icalproperty_method *lpicMethod, icaltimezone **lppicTZinfo, std::string *lpstrTZid, icalcomponent **lppEvent);
-	HRESULT HrSetTimeProperties(LPSPropValue lpMsgProps, ULONG ulMsgProps, icaltimezone *lpicTZinfo, std::string strTZid, icalcomponent *lpEvent);
-	
-};
-
+HRESULT HrGetFbInfo(icalcomponent *lpFbical, time_t *tStart, time_t *tEnd, std::string *lpstrUID, std::list<std::string> *lstUsers);
+HRESULT HrFbBlock2ICal(FBBlock_1 *lpsFbblk, LONG ulBlocks, time_t tStart, time_t tEnd, const std::string &strOrganiser, const std::string &strUser, const std::string &strUID, icalcomponent **lpicFbComponent);
 
 #endif
