@@ -58,7 +58,6 @@
 #include <libical/ical.h>
 
 
-
 typedef std::map<std::string, TIMEZONE_STRUCT> timezone_map;
 typedef std::map<std::string, TIMEZONE_STRUCT>::iterator timezone_map_iterator;
 
@@ -66,16 +65,16 @@ typedef std::map<std::string, TIMEZONE_STRUCT>::iterator timezone_map_iterator;
 time_t ICalTimeTypeToUTC(icalcomponent *lpicRoot, icalproperty *lpicProp);
 
 /* Function to convert time to local - used for All day events*/
-time_t ICalTimeTypeToLocal(icalcomponent *lpicRoot, icalproperty *lpicProp);
+time_t ICalTimeTypeToLocal(icalproperty *lpicProp);
 
 
 /* converts icaltimetype to local time_t */
 time_t icaltime_as_timet_with_server_zone(const struct icaltimetype tt);
 
-HRESULT HrParseVTimeZone(icalcomponent* lpVTZ /* in */, std::string* strTZID /* out */, TIMEZONE_STRUCT* lpTimeZone /* out */);
-HRESULT HrCreateVTimeZone(std::string strTZID /* in */, TIMEZONE_STRUCT &tsTimeZone /* in */, icalcomponent** lppVTZComp /* out */);
+HRESULT HrParseVTimeZone(icalcomponent* lpVTZ, std::string* strTZID, TIMEZONE_STRUCT* lpTimeZone);
+HRESULT HrCreateVTimeZone(const std::string &strTZID, TIMEZONE_STRUCT &tsTimeZone, icalcomponent** lppVTZComp);
 
 /* convert Olson timezone name (eg. Europe/Amsterdam) to internal TIMEZONE_STRUCT */
-HRESULT HrGetTzStruct(std::string strTimezone, TIMEZONE_STRUCT *tStruct);
+HRESULT HrGetTzStruct(const std::string &strTimezone, TIMEZONE_STRUCT *tStruct);
 
 #endif
