@@ -51,10 +51,9 @@
 #define ECMAPIUTILS
 
 #include <string>
-#include "vmime/dateTime.hpp"
+#include <vmime/dateTime.hpp>
 
-FILETIME		vmimeDatetimeToFiletime(vmime::datetime dt);
-vmime::datetime	FiletimeTovmimeDatetime(FILETIME ft);
-HRESULT			readStream(IStream *lpStream, std::string &strData);
+FILETIME vmimeDatetimeToFiletime(vmime::datetime dt);
+vmime::datetime FiletimeTovmimeDatetime(FILETIME ft);
 
 #endif
