@@ -51,6 +51,7 @@
 #define ECVMIMEUTILS
 
 #include <string>
+#include <set>
 #include <ECLogger.h>
 #include <vmime/vmime.hpp>
 #include "inetmapi.h"
@@ -58,26 +59,28 @@
 class ECVMIMESender : public ECSender
 {
 private:
-	vmime::messaging::session*		lpSess;
-	vmime::messaging::transport*	lpTransport;
 
-	HRESULT HrMakeRecipientsList(LPADRBOOK lpAdrBook, LPMESSAGE lpMessage, vmime::message *lpVMMessage, vmime::mailboxList& recipients);
-	HRESULT HrExpandGroup(LPADRBOOK lpAdrBook, LPSPropValue lpGroupName, LPSPropValue lpGroupEntryID, vmime::mailboxList& recipients, std::set<std::string> &setGroups, std::set<std::string> &setRecips);
-	HRESULT HrAddRecipsFromTable(LPADRBOOK lpAdrBook, IMAPITable *lpTable, vmime::mailboxList& recipients, std::set<std::string> &setGroups, std::set<std::string> &setRecips);
+	HRESULT HrMakeRecipientsList(LPADRBOOK lpAdrBook, LPMESSAGE lpMessage, vmime::ref<vmime::message> vmMessage, vmime::mailboxList &recipients);
+	HRESULT HrExpandGroup(LPADRBOOK lpAdrBook, LPSPropValue lpGroupName, LPSPropValue lpGroupEntryID, vmime::mailboxList &recipients, std::set<std::wstring> &setGroups, std::set<std::wstring> &setRecips);
+	HRESULT HrAddRecipsFromTable(LPADRBOOK lpAdrBook, IMAPITable *lpTable, vmime::mailboxList &recipients, std::set<std::wstring> &setGroups, std::set<std::wstring> &setRecips);
 
 public:
-	ECVMIMESender(ECLogger *newlpLogger, std::string strSMTPHost);
+	ECVMIMESender(ECLogger *newlpLogger, std::string strSMTPHost, int port);
 	virtual	~ECVMIMESender();
 
 #ifdef DEBUG
 	HRESULT printMail(vmime::message *lpVMMessage);
 #endif
-	HRESULT sendMail(LPADRBOOK lpAdrBook, LPMESSAGE lpMessage, vmime::message *lpVMMessage, char *lpszRawSMTP);
+	HRESULT sendMail(LPADRBOOK lpAdrBook, LPMESSAGE lpMessage, vmime::ref<vmime::message> vmMessage);
 };
 
-/* c-style util functions */
-void getShortFilename(std::string& strLongIn, std::string& strShortOut);
-void printComponent(vmime::component& comp);
-void componentToString(vmime::component& comp, std::string& strOut);
+class ECScreenSender : public ECSender
+{
+public:
+	ECScreenSender(ECLogger *newlpLogger);
+	virtual	~ECScreenSender();
+
+	HRESULT sendMail(vmime::ref<vmime::message> vmMessage);
+};
 
 #endif
