@@ -52,11 +52,11 @@
 
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2005 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
-// published by the Free Software Foundation; either version 2 of
+// published by the Free Software Foundation; either version 3 of
 // the License, or (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -64,36 +64,45 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 // General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// You should have received a copy of the GNU General Public License along
+// with this program; if not, write to the Free Software Foundation, Inc.,
+// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+//
+// Linking this library statically or dynamically with other modules is making
+// a combined work based on this library.  Thus, the terms and conditions of
+// the GNU General Public License cover the whole combination.
 //
 
-#ifndef MAPI_MESSAGING_SMTP_SMTPTRANSPORT_HPP_INCLUDED
-#define MAPI_MESSAGING_SMTP_SMTPTRANSPORT_HPP_INCLUDED
+#ifndef MAPI_NET_SMTP_SMTPTRANSPORT_HPP_INCLUDED
+#define MAPI_NET_SMTP_SMTPTRANSPORT_HPP_INCLUDED
 
 
 #include "vmime/config.hpp"
 
-#include "vmime/messaging/transport.hpp"
-#include "vmime/messaging/socket.hpp"
-#include "vmime/messaging/timeoutHandler.hpp"
+#include "vmime/net/transport.hpp"
+#include "vmime/net/socket.hpp"
+#include "vmime/net/timeoutHandler.hpp"
+
+#include "vmime/net/smtp/SMTPServiceInfos.hpp"
 
 #include "inetmapi.h"
 
 namespace vmime {
-namespace messaging {
+namespace net {
 namespace smtp {
 
 
-/** MAPISMTP transport service.
+class SMTPResponse;
+
+
+/** SMTP transport service.
   */
 
 class MAPISMTPTransport : public transport
 {
 public:
 
-	MAPISMTPTransport(session* sess, authenticator* auth);
+	MAPISMTPTransport(ref <session> sess, ref <security::authenticator> auth, const bool secured = false);
 	~MAPISMTPTransport();
 
 	const string getProtocolName() const;
@@ -102,72 +111,65 @@ public:
 	const serviceInfos& getInfos() const;
 
 	void connect();
-	const bool isConnected() const;
+	bool isConnected() const;
 	void disconnect();
 
 	void noop();
 
-	void send(const mailbox& expeditor, const mailboxList& recipients, utility::inputStream& is, const utility::stream::size_type size, utility::progressionListener* progress = NULL);
+	void send(const mailbox& expeditor, const mailboxList& recipients, utility::inputStream& is, const utility::stream::size_type size, utility::progressListener* progress = NULL);
 
+	bool isSecuredConnection() const;
+	ref <connectionInfos> getConnectionInfos() const;
+
+	// additional functions
 	const int getRecipientErrorCount() const;
 	const std::vector<sFailedRecip> getRecipientErrorList() const;
-
 	void setLogger(ECLogger *lpLogger);
 
+
 private:
 
-	static const int responseCode(const string& response);
-	static const string responseText(const string& response);
-
 	void sendRequest(const string& buffer, const bool end = true);
-
-	void readResponse(string& buffer);
+	ref <SMTPResponse> readResponse();
 
 	void internalDisconnect();
 
-	socket* m_socket;
+	void helo();
+	void authenticate();
+#if VMIME_HAVE_SASL_SUPPORT
+	void authenticateSASL();
+#endif // VMIME_HAVE_SASL_SUPPORT
+
+#if VMIME_HAVE_TLS_SUPPORT
+	void startTLS();
+#endif // VMIME_HAVE_TLS_SUPPORT
+
+	ref <socket> m_socket;
 	bool m_authentified;
+
 	bool m_extendedSMTP;
-	ECLogger *m_lpLogger;
+	std::map <string, std::vector <string> > m_extensions;
 
-	timeoutHandler* m_timeoutHandler;
+	ref <timeoutHandler> m_timeoutHandler;
+
+	const bool m_isSMTPS;
+
+	bool m_secured;
+	ref <connectionInfos> m_cntInfos;
 
-	std::vector<sFailedRecip> m_lstFailedRecipients;
 
 	// Service infos
-	class _infos : public serviceInfos
-	{
-	public:
+	static SMTPServiceInfos sm_infos;
 
-		struct props
-		{
-			// SMTP-specific options
-			serviceInfos::property PROPERTY_OPTIONS_NEEDAUTH;
-
-			// Common properties
-			serviceInfos::property PROPERTY_AUTH_USERNAME;
-			serviceInfos::property PROPERTY_AUTH_PASSWORD;
-
-			serviceInfos::property PROPERTY_SERVER_ADDRESS;
-			serviceInfos::property PROPERTY_SERVER_PORT;
-			serviceInfos::property PROPERTY_SERVER_SOCKETFACTORY;
-
-			serviceInfos::property PROPERTY_TIMEOUT_FACTORY;
-		};
-
-		const props& getProperties() const;
-
-		const string getPropertyPrefix() const;
-		const std::vector <serviceInfos::property> getAvailableProperties() const;
-	};
-
-	static _infos sm_infos;
+	// additional data
+	std::vector<sFailedRecip> m_lstFailedRecipients;
+	ECLogger *m_lpLogger;
 };
 
 
 } // smtp
-} // messaging
+} // net
 } // vmime
 
 
-#endif // MAPI_MESSAGING_SMTP_SMTPTRANSPORT_HPP_INCLUDED
+#endif // MAPI_NET_SMTP_SMTPTRANSPORT_HPP_INCLUDED
