@@ -55,11 +55,10 @@
 #include "mapidefs.h"
 #include "ECLogger.h"
 #include "options.h"
+#include "charset/convert.h"
 
-// We currently always write PR_BODY and PR_SUBJECT, etc as windows-1252
-// charset. This is good enough to support western-european e-mail
-// We don't set PR_INTERNET_CPID, and windows therefore assumes windows-1252
-#define MAPI_CHARSET vmime::charset(vmime::charsets::WINDOWS_1252)
+#define MAPI_CHARSET vmime::charset(vmime::charsets::UTF_8)
+#define MAPI_CHARSET_STRING "UTF-8"
 
 enum BODYLEVEL { BODY_NONE, BODY_PLAIN, BODY_HTML };
 enum ATTACHLEVEL { ATTACH_NONE, ATTACH_INLINE, ATTACH_NORMAL };
@@ -90,30 +89,44 @@ public:
 	VMIMEToMAPI(LPADRBOOK lpAdrBook, ECLogger *newlogger, delivery_options dopt);
 	virtual	~VMIMEToMAPI();
 
-	HRESULT convertVMIMEToMAPI(const string &input, IMessage *lpMessage);
+	HRESULT convertVMIMEToMAPI(const std::string &input, IMessage *lpMessage);
+	HRESULT createIMAPProperties(const std::string &input, std::string *lpEnvelope, std::string *lpBody, std::string *lpBodyStructure);
 
 private:
 	ECLogger *lpLogger;
-	bool delete_logger;
 	delivery_options m_dopt;
 	LPADRBOOK m_lpAdrBook;
 	IABContainer *m_lpDefaultDir;
 	sMailState m_mailState;
+	convert_context m_converter;
 
-	HRESULT fillMAPIMail(vmime::message* VMMessage, IMessage *lpMessage);
-	HRESULT disectBody(vmime::header* VMHeader, vmime::body* VMBody, IMessage* lpMessage, bool onlyBody = false, bool filterDouble = false, bool bAppendBody = false);
+	HRESULT fillMAPIMail(vmime::ref<vmime::message> vmMessage, IMessage *lpMessage);
+	HRESULT disectBody(vmime::ref<vmime::header> vmHeader, vmime::ref<vmime::body> vmBody, IMessage* lpMessage, bool onlyBody = false, bool filterDouble = false, bool bAppendBody = false);
 
-	HRESULT handleHeaders(vmime::header* VMHeader, IMessage* lpMessage);
-	HRESULT handleRecipients(vmime::header* VMHeader, IMessage* lpMessage);
-	HRESULT modifyRecipientList(LPADRLIST lpRecipients, const vmime::addressList* lpVMAddressList, ULONG ulRecipType);
-	HRESULT modifyFromAddressBook(LPSPropValue *lppPropVals, ULONG *lpulValues, const char *email, const char *fullname, ULONG ulRecipType, LPSPropTagArray lpPropsList);
+	HRESULT handleHeaders(vmime::ref<vmime::header> vmHeader, IMessage* lpMessage);
+	HRESULT handleRecipients(vmime::ref<vmime::header> vmHeader, IMessage* lpMessage);
+	HRESULT modifyRecipientList(LPADRLIST lpRecipients, vmime::ref<vmime::addressList> vmAddressList, ULONG ulRecipType);
+	HRESULT modifyFromAddressBook(LPSPropValue *lppPropVals, ULONG *lpulValues, const char *email, const WCHAR *fullname, ULONG ulRecipType, LPSPropTagArray lpPropsList);
 
-	HRESULT handleTextpart(vmime::header* VMHeader, vmime::body* VMBody, IMessage* lpMessage, bool bAppendBody);
-	HRESULT handleHTMLTextpart(vmime::header* VMHeader, vmime::body* VMBody, IMessage* lpMessage, bool bAppendBody);
-	HRESULT handleAttachment(vmime::header* VMHeader, vmime::body* VMBody, IMessage* lpMessage);
+	HRESULT handleTextpart(vmime::ref<vmime::header> vmHeader, vmime::ref<vmime::body> vmBody, IMessage* lpMessage, bool bAppendBody);
+	HRESULT handleHTMLTextpart(vmime::ref<vmime::header> vmHeader, vmime::ref<vmime::body> vmBody, IMessage* lpMessage, bool bAppendBody);
+	HRESULT handleAttachment(vmime::ref<vmime::header> vmHeader, vmime::ref<vmime::body> vmBody, IMessage* lpMessage, bool bAllowEmpty = true);
 	HRESULT handleMessageToMeProps(IMessage *lpMessage, LPADRLIST lpRecipients);
 	
 	HRESULT postWriteFixups(IMessage *lpMessage);
+
+	std::string mailboxToEnvelope(vmime::ref<vmime::mailbox> mbox);
+	std::string addressListToEnvelope(vmime::ref<vmime::addressList> mbox);
+	HRESULT createIMAPEnvelope(vmime::ref<vmime::message> vmMessage, IMessage* lpMessage);
+	std::string createIMAPEnvelope(vmime::ref<vmime::message> vmMessage);
+
+	HRESULT createIMAPBody(const std::string &input, vmime::ref<vmime::message> vmMessage, IMessage* lpMessage);
+
+	HRESULT messagePartToStructure(const std::string &input, vmime::ref<vmime::bodyPart> vmBodyPart, std::string *lpSimple, std::string *lpExtended);
+	HRESULT bodyPartToStructure(const std::string &input, vmime::ref<vmime::bodyPart> vmBodyPart, std::string *lpSimple, std::string *lpExtended);
+	std::string getStructureExtendedFields(vmime::ref<vmime::header> vmHeaderPart);
+	std::string parameterizedFieldToStructure(vmime::ref<vmime::parameterizedHeaderField> vmParamField);
+	std::string::size_type countBodyLines(const std::string &input, std::string::size_type start, std::string::size_type length);
 };
 
 #endif
