@@ -65,7 +65,7 @@ class ECLogger;
 
 typedef struct _sFailedRecip {
 	std::string strRecipEmail;
-	std::string strRecipName;
+	std::wstring strRecipName;
 	unsigned int ulSMTPcode;
 	std::string strSMTPResponse;
 } sFailedRecip;
@@ -75,31 +75,33 @@ typedef struct _sFailedRecip {
 class ECSender {
 protected:
 	std::string smtphost;
-	std::string error;
+	int smtpport;
+	std::wstring error;
 	int smtpresult;
 
 	std::vector<sFailedRecip> lstFailedRecipients;
 
 	ECLogger *lpLogger;
-	bool delete_logger;
 
 public:
-	ECSender(ECLogger *newlpLogger, const std::string &strSMTPHost);
+	ECSender(ECLogger *newlpLogger, const std::string &strSMTPHost, int port);
 	virtual	~ECSender();
 
 	virtual int getSMTPResult();
-	virtual const char* getErrorString();
+	virtual const WCHAR* getErrorString();
+	virtual void setError(const std::wstring &newError);
 	virtual void setError(const std::string &newError);
+	virtual bool haveError();
 
 	virtual const unsigned int getRecipientErrorCount() const;
 	virtual const unsigned int getRecipientErrorSMTPCode(unsigned int offset) const;
 	virtual const std::string getRecipientErrorText(unsigned int offset) const;
-	virtual const std::string getRecipientErrorDisplayName(unsigned int offset) const;
+	virtual const std::wstring getRecipientErrorDisplayName(unsigned int offset) const;
 	virtual const std::string getRecipientErrorEmailAddress(unsigned int offset) const;
 };
 
 /* c wrapper to create object */
-INETMAPI_API ECSender* CreateSender(ECLogger *lpLogger, const std::string &smtp);
+INETMAPI_API ECSender* CreateSender(ECLogger *lpLogger, const std::string &smtp, int port);
 
 // Read char Buffer and set properties on open lpMessage object
 INETMAPI_API HRESULT IMToMAPI(IMAPISession *lpSession, IMsgStore *lpMsgStore, IAddrBook *lpAddrBook, IMessage *lpMessage, const std::string &input, delivery_options dopt, ECLogger *lpLogger = NULL);
@@ -117,4 +119,7 @@ INETMAPI_API HRESULT IMToINet(IMAPISession *lpSession, IAddrBook *lpAddrBook, IM
 // Read properties from lpMessage object and send using  lpSMTPHost
 INETMAPI_API HRESULT IMToINet(IMAPISession *lpSession, IAddrBook *lpAddrBook, IMessage *lpMessage, ECSender *mailer, sending_options sopt, ECLogger *lpLogger);
 
+// Parse the RFC822 input and create IMAP Envelope, Body and Bodystructure property values
+INETMAPI_API HRESULT createIMAPProperties(const std::string &input, std::string *lpEnvelope, std::string *lpBody, std::string *lpBodyStructure);
+
 #endif // INETMAPI_H
