@@ -50,17 +50,18 @@
 #ifndef INPUT_STREAM_MAPI_ADAPTER_H
 #define INPUT_STREAM_MAPI_ADAPTER_H
 
-#include "vmime/utility/stream.hpp"
 #include "mapidefs.h"
+#include <vmime/utility/stream.hpp>
 
 class inputStreamMAPIAdapter : public vmime::utility::inputStream {
 public:
 	inputStreamMAPIAdapter(IStream *lpStream);
 	virtual ~inputStreamMAPIAdapter();
-	virtual const size_type read(value_type* const data, const size_type count);
-	virtual const size_type skip(const size_type count);
+
+	virtual size_type read(value_type* const data, const size_type count);
+	virtual size_type skip(const size_type count);
 	virtual void reset();
-	virtual const bool eof() const;
+	virtual bool eof() const;
 
 private:
 	bool	ateof;
