@@ -56,6 +56,7 @@
 typedef struct _do {
 	bool use_received_date;			// Use the 'received' date instead of the current date as delivery date
 	bool mark_as_read;				// Deliver the message 'read' instead of unread
+	bool add_imap_data;				// Save IMAP optimizations to the server
 	LPSBinary user_entryid;			// If not NULL, specifies the entryid of the user for whom we are delivering. If set, allows generating PR_MESSAGE_*_ME properties.
 } delivery_options;
 
@@ -66,6 +67,7 @@ typedef struct _so {
 	bool headers_only;
 	bool add_received_date;
 	bool force_tnef;
+	bool force_utf8;
 } sending_options;
 
 void INETMAPI_API imopt_default_delivery_options(delivery_options *dopt);
