@@ -50,14 +50,15 @@
 #ifndef OUTPUT_STREAM_MAPI_ADAPTER_H
 #define OUTPUT_STREAM_MAPI_ADAPTER_H
 
-#include "vmime/utility/stream.hpp"
 #include "mapidefs.h"
+#include <vmime/utility/stream.hpp>
 
 class outputStreamMAPIAdapter : public vmime::utility::outputStream {
 public:
 	outputStreamMAPIAdapter(IStream *lpStream);
 	virtual ~outputStreamMAPIAdapter();
 	void write(const value_type* const data, const size_type count);
+	void flush();
 
 private:
 	IStream *lpStream;
