@@ -50,16 +50,12 @@
 #ifndef _PublishFreeBusy_H_
 #define _PublishFreeBusy_H_
 
-#include "platform.h"
 #include <mapix.h>
 #include <mapidefs.h>
 #include <time.h>
-#include "CommonUtil.h"
-#include "restrictionutil.h"
+
 #include "freebusy.h"
-#include "ECFreeBusyUpdate.h"
-#include "freebusyutil.h"
-#include "ECFreeBusySupport.h"
+#include "CommonUtil.h"
 
 typedef struct{
 	ULONG ulType;
