@@ -47,7 +47,12 @@
  * 
  */
 
-/*! \page freebusy1 Free/Busy interface
+/**
+@file
+Free/busy Interface defines
+
+@defgroup libfreebusy Freebusy library
+@{
 
 The Free/Busy API allows mail providers to provide free/busy status information for specified 
 user accounts within a specified time range. The free/busy status of a block of time on a user's 
@@ -301,8 +306,8 @@ public:
 		The requested free/busy blocks are returned in this array.
 	 * @param[out] pcfetch Number of free/busy blocks actually returned in pblk.
 	 *
-	 * @return S_OK The requested number of blocks has been returned.
-	 * @return S_FALSE The requested number of blocks has not been returned.
+	 * @retval S_OK The requested number of blocks has been returned.
+	 * @retval S_FALSE The requested number of blocks has not been returned.
 	 */
 	virtual HRESULT __stdcall Next(LONG celt, FBBlock_1 *pblk, LONG *pcfetch) = 0;
 
@@ -312,7 +317,7 @@ public:
 	 *
 	 * @param[in] celt Number of free/busy blocks to skip.
 	 *
-	 * @return S_OK The requested number of blocks has been skiped.
+	 * @retval S_OK The requested number of blocks has been skiped.
 	 */
 	virtual HRESULT __stdcall Skip(LONG celt) = 0;
 
@@ -329,7 +334,7 @@ public:
 	 *
 	 * @param[out] ppclone Pointer to pointer to the copy of IEnumFBBlock interface.
 	 *
-	 * @return E_OUTOFMEMORY There is insufficient memory for making the copy.
+	 * @retval E_OUTOFMEMORY There is insufficient memory for making the copy.
 	 
 	 */
 	virtual HRESULT __stdcall Clone(IEnumFBBlock **ppclone) = 0;
@@ -520,7 +525,7 @@ public:
 	 * @param[out] pcRead 
 	 *		The actual number of users for which an IFreeBusyData interface has been found.
 	 *
-	 * @return S_OK 
+	 * @retval S_OK 
 	 *				The call is successful.
 	 */
 	virtual HRESULT __stdcall LoadFreeBusyData(	ULONG cMax, FBUser *rgfbuser, IFreeBusyData **prgfbdata,
@@ -544,9 +549,9 @@ public:
 	 * @param lpData4
 	 *			unknown param (always NULL? )
 	 *
-	 * @return S_OK
+	 * @retval S_OK
 	 *			The call is successful.
-	 * @return E_NOTIMPL 
+	 * @retval E_NOTIMPL 
 	 *			The is not supported.
 	 *
 	 * @todo research for lpDate4
@@ -647,7 +652,7 @@ public:
 	 * @param[out] prtmStart The start time of the publish range (should be ULONG)
 	 * @param[out] prtmEnd The end time of the publish range (should be ULONG)
 	 * 
-	 * @return E_NOTIMPL 
+	 * @retval E_NOTIMPL 
 	 *				Not supported, client should send a meeting request
 	 *
 	 * @todo change type of prtmStart and prtmEnd from unsigned int to LONG
@@ -775,3 +780,5 @@ public:
 };
 
 #endif // FREEBUSY_INCLUDED
+
+/** @} */
