@@ -133,21 +133,21 @@ public:
 	time_t getModifiedStartDateTime(ULONG id);
 	time_t getModifiedEndDateTime(ULONG id);
 	time_t getModifiedOriginalDateTime(ULONG id); /* used as recurrence-id */
-	std::string getModifiedSubject(ULONG id);
+	std::wstring getModifiedSubject(ULONG id);
 	ULONG getModifiedMeetingType(ULONG id);
 	LONG getModifiedReminderDelta(ULONG id);
 	ULONG getModifiedReminder(ULONG id);
-	std::string getModifiedLocation(ULONG id);
+	std::wstring getModifiedLocation(ULONG id);
 	ULONG getModifiedBusyStatus(ULONG id);
 	ULONG getModifiedAttachment(ULONG id);
 	ULONG getModifiedSubType(ULONG id);
 
 	HRESULT addModifiedException(time_t tStart, time_t tEnd, time_t tOriginalStart, ULONG *id);
-	HRESULT setModifiedSubject(ULONG id, std::string strSubject);
+	HRESULT setModifiedSubject(ULONG id, std::wstring strSubject);
 	HRESULT setModifiedMeetingType(ULONG id, ULONG type);
 	HRESULT setModifiedReminderDelta(ULONG id, LONG delta);
 	HRESULT setModifiedReminder(ULONG id, ULONG set);
-	HRESULT setModifiedLocation(ULONG id, std::string strLocation);
+	HRESULT setModifiedLocation(ULONG id, std::wstring strLocation);
 	HRESULT setModifiedBusyStatus(ULONG id, ULONG status);
 	HRESULT setModifiedAttachment(ULONG id);
 	HRESULT setModifiedSubType(ULONG id, ULONG subtype);
@@ -210,6 +210,9 @@ public:
 private:
 	RecurrenceState m_sRecState;
 
+	std::vector<std::wstring> vExceptionsSubject;
+	std::vector<std::wstring> vExceptionsLocation;
+
 /*
 	std::list<time_t> exceptions;
 	std::list<time_t> deleted_occurrences;	
