@@ -64,12 +64,12 @@ public:
 	virtual ULONG __stdcall Release();
 	virtual HRESULT __stdcall QueryInterface(REFIID iid, void **lpvoid);
 
-	virtual HRESULT GetLastError(HRESULT hr, ULONG ulFlags, LPMAPIERROR *lppMAPIError);
-	virtual HRESULT Config(LPSTREAM lpState, ULONG ulFlags);
-	virtual HRESULT UpdateState(LPSTREAM lpState);
+	virtual HRESULT __stdcall GetLastError(HRESULT hr, ULONG ulFlags, LPMAPIERROR *lppMAPIError);
+	virtual HRESULT __stdcall Config(LPSTREAM lpState, ULONG ulFlags);
+	virtual HRESULT __stdcall UpdateState(LPSTREAM lpState);
 			
-	virtual HRESULT ImportABChange(ULONG ulObjType, ULONG cbObjId, LPENTRYID lpObjId);
-	virtual HRESULT ImportABDeletion(ULONG ulType, ULONG cbObjId, LPENTRYID lpObjId);
+	virtual HRESULT __stdcall ImportABChange(ULONG ulObjType, ULONG cbObjId, LPENTRYID lpObjId);
+	virtual HRESULT __stdcall ImportABDeletion(ULONG ulType, ULONG cbObjId, LPENTRYID lpObjId);
 
 private:
 	IECServiceAdmin *m_lpSrcServiceAdmin;
