@@ -53,6 +53,14 @@
 #include "ECLibSync.h"
 #include <pthread.h>
 
+
+#define EC_SYNC_OPT_STREAM			1
+#define EC_SYNC_OPT_CHANGENOTIF		2
+#define EC_SYNC_OPT_STATECOLLECT	4
+#define EC_SYNC_OPT_CONTINUOUS		8	// Not included in EC_SYNC_OPT_ALL
+#define EC_SYNC_OPT_ALL				(EC_SYNC_OPT_STREAM | EC_SYNC_OPT_CHANGENOTIF | EC_SYNC_OPT_STATECOLLECT)
+
+
 class ECLIBSYNC_API ECSyncSettings
 {
 public:
@@ -68,6 +76,11 @@ public:
 	bool	ChangeNotificationsEnabled() const;
 	bool	StateCollectorEnabled() const;
 
+	// Update settings
+	bool	EnableSyncLog(bool bEnable);
+	ULONG	SetSyncLogLevel(ULONG ulLogLevel);
+	ULONG	SetSyncOptions(ULONG ulOptions);
+
 private:
 	ECSyncSettings();
 
