@@ -646,9 +646,6 @@ SCODE ScCreateConversationIndex (ULONG cbParent,
 HRESULT WrapStoreEntryID (ULONG ulFlags, LPTSTR lpszDLLName, ULONG cbOrigEntry,
 			  LPENTRYID lpOrigEntry, ULONG *lpcbWrappedEntry, LPENTRYID *lppWrappedEntry);
 
-/* Unwrap store entryid, not an orginal mapi function */
-HRESULT UnWrapStoreEntryID(ULONG cbOrigEntry, LPENTRYID lpOrigEntry, ULONG *lpcbUnWrappedEntry, LPENTRYID *lppUnWrappedEntry);
-
 /* RTF Sync Utilities */
 
 #define RTF_SYNC_RTF_CHANGED    ((ULONG) 0x00000001)
