@@ -114,7 +114,7 @@ typedef MAPIINIT *LPMAPIINIT;
 
 #define MAPI_MULTITHREAD_NOTIFICATIONS  0x00000001
 /* Reserved for MAPI                    0x40000000 */
-/* #define MAPI_NT_SERVICE              0x00010000  Use from NT service */
+#define MAPI_NT_SERVICE              0x00010000  /* Use from NT service */
 
 /* MAPI base functions */
 
