@@ -53,9 +53,13 @@
 #include <mapidefs.h>
 #include <mapix.h>
 #include <string>
-#include "ECLogger.h"
 #include "ECTags.h"
+#include "charset/utf32string.h"
+#include <list>
 
+#include "ustringutil.h"
+
+class ECLogger;
 
 // Newmail Notify columns
 const static SizedSPropTagArray(4, sPropNewMailColumns) =
@@ -86,104 +90,16 @@ enum
 #define CLIENT_VERSION_OLK2007			12
 #define CLIENT_VERSION_OLK2010			14
 
-// The ucs2string type
-// WARNING, this is different from wstring !
-typedef std::basic_string<WCHAR> ucs2string;
-
-// char_traits<WCHAR> is already present in win32
-namespace std {
-
-template<>
-    struct char_traits<WCHAR>
-    {
-      typedef WCHAR	        char_type;
-      typedef wint_t            int_type;
-      typedef streamoff         off_type;
-      typedef wstreampos        pos_type;
-      typedef mbstate_t         state_type;
-
-      static void
-      assign(char_type& __c1, const char_type& __c2)
-      { __c1 = __c2; }
-
-      static bool
-      eq(const char_type& __c1, const char_type& __c2)
-      { return __c1 == __c2; }
-
-      static bool
-      lt(const char_type& __c1, const char_type& __c2)
-      { return __c1 < __c2; }
-
-      static int
-      compare(const char_type* __s1, const char_type* __s2, size_t __n)
-      { while(*__s1 != 0 && *__s2 != 0) { 
-		if(*__s1 != *__s2) return *__s1 - *__s2;
-		__s1++; __s2++;
-	}
-	if(*__s1 == 0 && *__s2 == 0) return 0;
-	if(*__s1 != 0) return -1;
-	return 1;
-      }
-
-      static size_t
-      length(const char_type* __s)
-      { int l = 0;
-	while(*__s != 0) { l++; __s++; }
-	return l; 
-      }
-
-      static const char_type* 
-      find(const char_type* __s, size_t __n, const char_type& __a)
-      { while(*__s != 0 && __n > 0) { 
-	  if(*__s == __a) return __s; 
-	__s++; __n--; 
-	}
-	return NULL;
-      }
-
-      static char_type* 
-      move(char_type* __s1, const char_type* __s2, int_type __n)
-      { return (WCHAR *)memmove((void *)__s1, (void *)__s2, __n*sizeof(WCHAR)); }
-
-      static char_type* 
-      copy(char_type* __s1, const char_type* __s2, size_t __n)
-      { return (WCHAR *)memcpy((void *)__s1, (void *)__s2, __n*sizeof(WCHAR)); }
-
-      static char_type* 
-      assign(char_type* __s, size_t __n, char_type __a)
-      { char_type *__o = __s;
-	while(__n>0) {*__s = __a; __n--; __s++; }
-	return  __o;
-      }
-
-      static char_type 
-      to_char_type(const int_type& __c) { return char_type(__c); }
-
-      static int_type 
-      to_int_type(const char_type& __c) { return int_type(__c); }
-
-      static bool 
-      eq_int_type(const int_type& __c1, const int_type& __c2)
-      { return __c1 == __c2; }
-
-      static int_type 
-      eof() { return static_cast<int_type>(WEOF); }
-
-      static int_type 
-      not_eof(const int_type& __c)
-      { return eq_int_type(__c, eof()) ? 0 : __c; }
-  };
-}
-
 /* darn, no sane place because of depend include on mapidefs.h */
 bool operator ==(SBinary a, SBinary b);
 bool operator <(SBinary a, SBinary b);
 
 #define CLIENT_ADMIN_SOCKET "file:///var/run/zarafa"
 char* GetServerUnixSocket(char* szPreferred = NULL);
+std::string GetServerFQDN();
 
-HRESULT HrOpenECAdminSession(IMAPISession **lppSession, char *szPath = NULL, ULONG ulProfileFlags = 0, char *sslkey_file = NULL, char *sslkey_password = NULL);
-HRESULT HrOpenECSession(IMAPISession **lppSession, char *szUsername, char *szPassword, char *szPath = NULL, ULONG ulProfileFlags = 0, char *sslkey_file = NULL, char *sslkey_password = NULL, char *profname = NULL);
+HRESULT HrOpenECAdminSession(IMAPISession **lppSession, const char *szPath = NULL, ULONG ulProfileFlags = 0, const char *sslkey_file = NULL, const char *sslkey_password = NULL);
+HRESULT HrOpenECSession(IMAPISession **lppSession, const WCHAR *szUsername, const WCHAR *szPassword, const char *szPath = NULL, ULONG ulProfileFlags = 0, const char *sslkey_file = NULL, const char *sslkey_password = NULL, const char *profname = NULL);
 HRESULT HrSearchECStoreEntryId(IMAPISession *lpMAPISession, BOOL bPublic, ULONG *lpcbEntryID, LPENTRYID *lppEntryID);
 HRESULT HrOpenDefaultStore(IMAPISession *lpMAPISession, IMsgStore **lppMsgStore);
 HRESULT HrOpenDefaultStore(IMAPISession *lpMAPISession, ULONG ulFlags, IMsgStore **lppMsgStore);
@@ -197,48 +113,54 @@ HRESULT HrOpenECPublicStoreOnline(IMAPISession *lpMAPISession, IMsgStore **lppMs
 
 HRESULT GetProxyStoreObject(IMsgStore *lpMsgStore, IMsgStore **lppMsgStore);
 
-HRESULT HrAddECMailBox(LPMAPISESSION lpSession, char *lpszUserName);
-HRESULT HrAddECMailBox(LPPROVIDERADMIN lpProviderAdmin, char * lpszUserName);
+HRESULT HrAddECMailBox(LPMAPISESSION lpSession, LPCWSTR lpszUserName);
+HRESULT HrAddECMailBox(LPPROVIDERADMIN lpProviderAdmin, LPCWSTR lpszUserName);
 
 HRESULT HrRemoveECMailBox(LPMAPISESSION lpSession, LPMAPIUID lpsProviderUID);
 HRESULT HrRemoveECMailBox(LPPROVIDERADMIN lpProviderAdmin, LPMAPIUID lpsProviderUID);
 
-HRESULT ECCreateOneOff(char* lpszName, char* lpszAdrType, char* lpszAddress, ULONG ulFlags, ULONG* lpcbEntryID, LPENTRYID* lppEntryID);
-HRESULT ECParseOneOff(LPENTRYID lpEntryID, ULONG cbEntryID, std::string &strName, std::string &strType, std::string &strEmailAddress);
+HRESULT ECCreateOneOff(LPTSTR lpszName, LPTSTR lpszAdrType, LPTSTR lpszAddress, ULONG ulFlags, ULONG* lpcbEntryID, LPENTRYID* lppEntryID);
+HRESULT ECParseOneOff(LPENTRYID lpEntryID, ULONG cbEntryID, std::wstring &strWName, std::wstring &strWType, std::wstring &strWAddress);
 
-HRESULT HrGetAddress(IMAPISession *lpSession, LPSPropValue lpProps, ULONG cValues, ULONG ulPropTagEntryID, ULONG ulPropTagName, ULONG ulPropTagType, ULONG ulPropTagEmailAddress, std::string &strName, std::string &strType, std::string &strEmailAddress);
-HRESULT HrGetAddress(IMAPISession *lpSession, IMessage *lpMessage, ULONG ulPropTagEntryID, ULONG ulPropTagName, ULONG ulPropTagType, ULONG ulPropTagEmailAddress, std::string &strName, std::string &strType, std::string &strEmailAddress);
-HRESULT HrGetAddress(LPADRBOOK lpAdrBook, IMessage *lpMessage, ULONG ulPropTagEntryID, ULONG ulPropTagName, ULONG ulPropTagType, ULONG ulPropTagEmailAddress, std::string &strName, std::string &strType, std::string &strEmailAddress);
-HRESULT HrGetAddress(LPADRBOOK lpAdrBook, LPSPropValue lpProps, ULONG cValues, ULONG ulPropTagEntryID, ULONG ulPropTagName, ULONG ulPropTagType, ULONG ulPropTagEmailAddress, std::string &strName, std::string &strType, std::string &strEmailAddress);
-HRESULT HrGetAddress(LPADRBOOK lpAdrBook, LPENTRYID lpEntryID, ULONG cbEntryID, std::string &strName, std::string &strType, std::string &strEmailAddress);
+HRESULT HrGetAddress(IMAPISession *lpSession, LPSPropValue lpProps, ULONG cValues, ULONG ulPropTagEntryID, ULONG ulPropTagName, ULONG ulPropTagType, ULONG ulPropTagEmailAddress,
+					 std::wstring &strName, std::wstring &strType, std::wstring &strEmailAddress);
+HRESULT HrGetAddress(IMAPISession *lpSession, IMessage *lpMessage, ULONG ulPropTagEntryID, ULONG ulPropTagName, ULONG ulPropTagType, ULONG ulPropTagEmailAddress,
+					 std::wstring &strName, std::wstring &strType, std::wstring &strEmailAddress);
+HRESULT HrGetAddress(LPADRBOOK lpAdrBook, IMessage *lpMessage, ULONG ulPropTagEntryID, ULONG ulPropTagName, ULONG ulPropTagType, ULONG ulPropTagEmailAddress,
+					 std::wstring &strName, std::wstring &strType, std::wstring &strEmailAddress);
+HRESULT HrGetAddress(LPADRBOOK lpAdrBook, LPSPropValue lpProps, ULONG cValues, ULONG ulPropTagEntryID, ULONG ulPropTagName, ULONG ulPropTagType, ULONG ulPropTagEmailAddress,
+					 std::wstring &strName, std::wstring &strType, std::wstring &strEmailAddress);
+HRESULT HrGetAddress(LPADRBOOK lpAdrBook, LPENTRYID lpEntryID, ULONG cbEntryID, std::wstring &strName, std::wstring &strType, std::wstring &strEmailAddress);
 
-HRESULT HrConvertToWString(const std::string &strInput, const std::string &strCharset, ucs2string &wstrOutput);
-HRESULT HrConvertFromWString(const ucs2string &wstrInput, const std::string &strCharset, std::string &strOutput);
-HRESULT HrEscapeHTML(ucs2string &wstrInput, std::string &strOutput);
-HRESULT HrToQuotedPrintable1252(std::string &input, std::string *output, bool header = true);
+std::string ToQuotedPrintable(const std::string &input, std::string charset, bool header = true, bool imap = false);
+std::string ToQuotedBase64Header(const std::string &input, std::string charset);
+std::string ToQuotedBase64Header(const std::wstring &input);
 
 HRESULT HrNewMailNotification(IMsgStore* lpMDB, IMessage* lpMessage);
 HRESULT HrCreateEmailSearchKey(char* lpszEmailType, char* lpszEmail, ULONG* cb, LPBYTE* lppByte);
 
 HRESULT DoSentMail(IMAPISession *lpSession, IMsgStore *lpMDB, ULONG ulFlags, IMessage *lpMessage);
 
-HRESULT TestRestriction(LPSRestriction lpCondition, ULONG cValues, LPSPropValue lpPropVals, ULONG ulLevel = 0);
-HRESULT TestRestriction(LPSRestriction lpCondition, IMAPIProp *lpMessage, ULONG ulLevel = 0);
+HRESULT TestRestriction(LPSRestriction lpCondition, ULONG cValues, LPSPropValue lpPropVals, const ECLocale &locale, ULONG ulLevel = 0);
+HRESULT TestRestriction(LPSRestriction lpCondition, IMAPIProp *lpMessage, const ECLocale &locale, ULONG ulLevel = 0);
 
 HRESULT GetClientVersion(unsigned int* ulVersion);
 
-HRESULT CreateProfileTemp(char *username, char *password, char *path, char* szProfName, ULONG ulProfileFlags,
-						  char *sslkey_file, char *sslkey_password);
+HRESULT CreateProfileTemp(const WCHAR *username, const WCHAR *password, const char *path, const char* szProfName, ULONG ulProfileFlags,
+						  const char *sslkey_file, const char *sslkey_password);
 HRESULT DeleteProfileTemp(char *szProfName);
-HRESULT OpenSubFolder(LPMDB lpMDB, char *folder, char psep, ECLogger *lpLogger, bool blIsPublic, bool bCreateFolder, LPMAPIFOLDER *lppSubFolder);
-HRESULT FindFolder(LPMAPITABLE lpTable, const char *folder, LPSPropValue *lppFolderProp);
 
-HRESULT HrOpenUserMsgStore(LPMAPISESSION lpSession, char *lpszUser, LPMDB *lppStore);
+HRESULT OpenSubFolder(LPMDB lpMDB, const WCHAR *folder, WCHAR psep, ECLogger *lpLogger, bool bIsPublic, bool bCreateFolder, LPMAPIFOLDER *lppSubFolder);
+HRESULT FindFolder(LPMAPITABLE lpTable, const WCHAR *folder, LPSPropValue *lppFolderProp);
+
+HRESULT HrOpenUserMsgStore(LPMAPISESSION lpSession, WCHAR *lpszWUser, LPMDB *lppStore);
 
 HRESULT HrOpenDefaultCalendar(LPMDB lpMsgStore, ECLogger *lpLogger, LPMAPIFOLDER *lpDefFolder);
 
 HRESULT HrGetPropTags(char **names, IMAPIProp *lpProp, LPSPropTagArray *lppPropTagArray);
 
+HRESULT __stdcall UnWrapStoreEntryID(ULONG cbOrigEntry, LPENTRYID lpOrigEntry, ULONG *lpcbUnWrappedEntry, LPENTRYID *lppUnWrappedEntry);
+
 /**
  * NAMED PROPERTY utilities
  *
