@@ -67,12 +67,23 @@ struct MAPIResultCodes
 	const char* error;
 };
 
+struct INFOGUID {
+	int		ulType; //0=mapi,1=exchange,2=new,3=zarafa,4=windows/other, 10=ontdekte
+	GUID	*guid;
+	char*	szguidname;
+};
+
 std::string GetMAPIErrorDescription( HRESULT hResult );
 
+std::string DBGGUIDToString(REFIID iid);
+std::string MapiNameIdListToString(ULONG cNames, LPMAPINAMEID * ppNames, LPSPropTagArray pptaga = NULL);
+std::string MapiNameIdToString(LPMAPINAMEID pNameId);
+
 std::string PropNameFromPropTagArray(LPSPropTagArray lpPropTagArray);
 std::string PropNameFromPropArray(ULONG cValues, LPSPropValue lpPropArray);
 std::string PropNameFromPropTag(ULONG ulPropTag);
 std::string RestrictionToString(LPSRestriction lpRestriction, unsigned int indent=0);
+std::string RowToString(LPSRow lpRow);
 std::string RowSetToString(LPSRowSet lpRows);
 std::string AdrRowSetToString(LPADRLIST lpAdrList, LPFlagList lpFlagList);
 
@@ -82,6 +93,10 @@ std::string SortOrderSetToString(LPSSortOrderSet lpSortCriteria);
 std::string NotificationToString(ULONG cNotification, LPNOTIFICATION lpNotification);
 
 std::string ProblemArrayToString(LPSPropProblemArray lpProblemArray);
+std::string unicodetostr(WCHAR *lpszW);
+
+const char *MsgServiceContextToString(ULONG ulContext);
+const char *ResourceTypeToString(ULONG ulResourceType);
 
 //Internal used only
 std::string RelationalOperatorToString(ULONG relop);
