@@ -168,12 +168,12 @@ typedef struct _sECEntryId
 typedef struct _sECServerNameList
 {
 	unsigned int	cServers;
-	char**			lpszaServer;
+	LPTSTR*			lpszaServer;
 } ECSVRNAMELIST, *LPECSVRNAMELIST;
 
 typedef struct _sPropmapEntry {
 	unsigned int	ulPropId;
-	char*			lpszValue;
+	LPTSTR			lpszValue;
 } SPROPMAPENTRY, *LPSPROPMAPENTRY;
 
 typedef struct _sPropmap {
@@ -184,7 +184,7 @@ typedef struct _sPropmap {
 typedef struct _sMVPropmapEntry {
 	unsigned int	ulPropId;
 	int				cValues;
-	char**			lpszValues;
+	LPTSTR*			lpszValues;
 } MVPROPMAPENTRY, *LPMVPROPMAPENTRY;
 
 typedef struct _sMVPropmap {
@@ -193,11 +193,11 @@ typedef struct _sMVPropmap {
 } MVPROPMAP, *LPMVPROPMAP;
 
 typedef struct _sECUser {
-	char*			lpszUsername;	// username@companyname
-	char*			lpszPassword;
-	char*			lpszFullEmail;
-	char*			lpszFullName;
-	char*			lpszServername;
+	LPTSTR			lpszUsername;	// username@companyname
+	LPTSTR			lpszPassword;
+	LPTSTR			lpszMailAddress;
+	LPTSTR			lpszFullName;
+	LPTSTR			lpszServername;
 	objectclass_t	ulObjClass;
 	unsigned int	ulIsAdmin;		// See userobject_admin_level_t
 	unsigned int	ulIsABHidden;	// Is user hidden from address book
@@ -208,9 +208,9 @@ typedef struct _sECUser {
 } ECUSER, *LPECUSER;
 
 typedef struct _sECGroup {
-	char*			lpszGroupname; // groupname@companyname
-	char*			lpszFullname;
-	char*			lpszFullEmail;
+	LPTSTR			lpszGroupname; // groupname@companyname
+	LPTSTR			lpszFullname;
+	LPTSTR			lpszFullEmail;
 	ECENTRYID		sGroupId;
 	unsigned int	ulIsABHidden;	// Is group hidden from address book
 	SPROPMAP		sPropmap;		// Extra anonymous properties for addressbook
@@ -219,8 +219,8 @@ typedef struct _sECGroup {
 
 typedef struct _sECCompany {
 	ECENTRYID		sAdministrator; // userid of the administrator
-	char*			lpszCompanyname;
-	char*			lpszServername;
+	LPTSTR			lpszCompanyname;
+	LPTSTR			lpszServername;
 	ECENTRYID		sCompanyId;
 	unsigned int	ulIsABHidden;	// Is company hidden from address book
 	SPROPMAP		sPropmap;		// Extra anonymous properties for addressbook
@@ -234,13 +234,6 @@ typedef struct _sECPermission {
 	ECENTRYID		sUserId;
 }ECPERMISSION, *LPECPERMISSION;
 
-typedef struct _sECUserObject {
-	char*				lpszName;		// Fullname or fallback on username/groupname (name@companyname)
-	unsigned int		ulId;			// User or group id
-	ECENTRYID			sId;			// User or group eid
-	objectclass_t		type;			// User type (user, group, etc...)
-}ECUSEROBJECT, *LPECUSEROBJECT;
-
 typedef struct _sECQuota {
 	bool			bUseDefaultQuota;
 	bool			bIsUserDefaultQuota; // Default quota for users within company
@@ -255,11 +248,11 @@ typedef struct _sECQuotaStatus {
 }ECQUOTASTATUS, *LPECQUOTASTATUS;
 
 typedef struct _sECServer {
-	char*	lpszName;
-	char*	lpszFilePath;
-	char*	lpszHttpPath;
-	char*	lpszSslPath;
-	char*	lpszPreferedPath;
+	LPTSTR	lpszName;
+	LPTSTR	lpszFilePath;
+	LPTSTR	lpszHttpPath;
+	LPTSTR	lpszSslPath;
+	LPTSTR	lpszPreferedPath;
 	ULONG	ulFlags;
 }ECSERVER, *LPECSERVER;
 
@@ -283,4 +276,7 @@ typedef struct _sECServerList {
 
 #define EC_SDFLAG_IS_PEER	0x00000001
 
+// CreateStore flag(s)
+#define EC_OVERRIDE_HOMESERVER			0x00000001
+
 #endif
