@@ -50,7 +50,7 @@
 #ifndef ICONV_H
 #define ICONV_H
 
-#include <iconv.h>
+#include "charset/convert.h"
 #include <string>
 
 class ECIConv {
@@ -62,7 +62,8 @@ public:
     std::string convert(const std::string &input);
 
 private:
-    iconv_t m_cd;
+	typedef details::iconv_context<std::string, std::string> context_t;
+	context_t *m_lpContext;
 };
 
 #endif
