@@ -129,12 +129,14 @@ struct idcompare
 
 #define TABLEROW_FLAG_DESC		0x00000001
 #define TABLEROW_FLAG_FLOAT		0x00000002
+#define TABLEROW_FLAG_STRING	0x00000004
 
 class ECTableRow {
 public:
 	ECTableRow(sObjectTableKey sKey, unsigned int ulSortCols, unsigned int *lpSortLen, unsigned char *lpFlags, unsigned char **lppSortData, bool fHidden);
 	~ECTableRow();
 
+	unsigned int GetObjectSize();
 
 	static bool rowcompare(ECTableRow *a, ECTableRow *b);
 	static bool rowcompare(unsigned int ulSortColsA, int *lpSortLenA, unsigned char **lppSortKeysA, unsigned char *lpSortFlagsA, unsigned int ulSortColsB, int *lpSortLenB, unsigned char **lppSortKeysB, unsigned char *lpSortFlagsB);
@@ -199,8 +201,10 @@ public:
 
 	// Returns the first row where the sort columns are not less than the specified sortkey
 	ECRESULT	LowerBound(unsigned int ulSortColPrefixLen, int *lpSortLen, unsigned char **lppSortData, unsigned char *lpFlags);
-	ECRESULT 	Find(unsigned int ulSortCols, int *lpSortLen, unsigned char **lppSortData, unsigned char *lpFlags);
-	
+	ECRESULT 	Find(unsigned int ulSortCols, int *lpSortLen, unsigned char **lppSortData, unsigned char *lpFlags, sObjectTableKey *lpsKey);
+
+	unsigned int GetObjectSize();
+
 private:
 	ECRESULT	UpdateCounts(ECTableRow *lpRow);
 	ECRESULT	CurrentRow(ECTableRow *lpRow, unsigned int *lpulCurrentRow);
