@@ -58,6 +58,7 @@
 
 #include "ECKeyTable.h"
 #include "ECUnknown.h"
+#include "ustringutil.h"
 
 typedef struct {
 	LPSPropValue	lpsPropVal;
@@ -99,9 +100,9 @@ protected:
 public:
 	static  HRESULT Create(LPSPropTagArray lpsPropTagArray, ULONG ulRowPropTag, ECMemTable **lppRecipTable);
 
-	virtual HRESULT QueryInterface(REFIID refiid, void **lpvoid);
+	virtual HRESULT QueryInterface(REFIID refiid, void **lppInterface);
 
-	virtual HRESULT HrGetView(ECMemTableView **lpView);
+	virtual HRESULT HrGetView(const ECLocale &locale, ULONG ulFlags, ECMemTableView **lpView);
 
 	virtual HRESULT HrModifyRow(ULONG ulFlags, LPSPropValue lpId, LPSPropValue lpProps, ULONG cValues);
 	
@@ -133,12 +134,12 @@ protected:
 
 class ECMemTableView : public ECUnknown {
 protected:
-	ECMemTableView(ECMemTable *lpMemTable);
+	ECMemTableView(ECMemTable *lpMemTable, const ECLocale &locale, ULONG ulFlags);
 	virtual ~ECMemTableView();
 public:
-	static HRESULT	Create(ECMemTable *lpMemTable, ECMemTableView **lppMemTableView);
+	static HRESULT	Create(ECMemTable *lpMemTable, const ECLocale &locale, ULONG ulFlags, ECMemTableView **lppMemTableView);
 
-	virtual HRESULT QueryInterface(REFIID refiid, void **lpvoid);
+	virtual HRESULT QueryInterface(REFIID refiid, void **lppInterface);
 	virtual HRESULT UpdateRow(ULONG ulUpdateType, ULONG ulId);
 	virtual HRESULT Clear();
 
@@ -170,7 +171,7 @@ public:
 		// IUnknown
 		virtual ULONG __stdcall AddRef();
 		virtual ULONG __stdcall Release();
-		virtual HRESULT __stdcall QueryInterface(REFIID refiid, void **pInterface);
+		virtual HRESULT __stdcall QueryInterface(REFIID refiid, void **lppInterface);
 
 		// From IMAPITable
 		virtual HRESULT __stdcall GetLastError(HRESULT hResult, ULONG ulFlags, LPMAPIERROR *lppMAPIError);
@@ -212,6 +213,8 @@ private:
 	ECMemTable *			lpMemTable;
 	ECMapMemAdvise			m_mapAdvise;
 	ULONG					m_ulConnection; // Next advise id
+	ECLocale				m_locale;
+	ULONG					m_ulFlags;
 
 	virtual HRESULT UpdateSortOrRestrict();
 
