@@ -58,17 +58,22 @@
 //
 
 #define PR_EC_PATH						PROP_TAG(PT_STRING8,	PR_EC_BASE+0x00)
-#define PR_EC_USERNAME					PROP_TAG(PT_STRING8,	PR_EC_BASE+0x01)
-#define PR_EC_USERPASSWORD				PROP_TAG(PT_STRING8,	PR_EC_BASE+0x02)
+#define PR_EC_USERNAME					PROP_TAG(PT_TSTRING,	PR_EC_BASE+0x01)
+#define PR_EC_USERNAME_A				PROP_TAG(PT_STRING8,	PR_EC_BASE+0x01)
+#define PR_EC_USERNAME_W				PROP_TAG(PT_UNICODE,	PR_EC_BASE+0x01)
+#define PR_EC_USERPASSWORD				PROP_TAG(PT_TSTRING,	PR_EC_BASE+0x02)
+#define PR_EC_USERPASSWORD_A			PROP_TAG(PT_STRING8,	PR_EC_BASE+0x02)
+#define PR_EC_USERPASSWORD_W			PROP_TAG(PT_UNICODE,	PR_EC_BASE+0x02)
 #define PR_EC_PORT						PROP_TAG(PT_STRING8,	PR_EC_BASE+0x03)
 #define PR_EC_FLAGS						PROP_TAG(PT_LONG,		PR_EC_BASE+0x04)
 #define PR_EC_SSLKEY_FILE				PROP_TAG(PT_STRING8,	PR_EC_BASE+0x05)
 #define PR_EC_SSLKEY_PASS				PROP_TAG(PT_STRING8,	PR_EC_BASE+0x06)
-//#define PR_EC_SSLKEY_CERT				PROP_TAG(PT_STRING8,	PR_EC_BASE+0x07)
-//#define PR_EC_PROFILE_USER			PROP_TAG(PT_BINARY,		PR_EC_BASE+0x08)
 #define PR_EC_LAST_CONNECTIONTYPE		PROP_TAG(PT_LONG,		PR_EC_BASE+0x09)
 #define PR_EC_CONNECTION_TIMEOUT		PROP_TAG(PT_LONG,		PR_EC_BASE+0x0A)
-#define PR_EC_OFFLINE_PATH				PROP_TAG(PT_STRING8,	PR_EC_BASE+0x10) /* same as PR_EC_CONTACT_ENTRYID, but on different objects! */
+#define PR_EC_MSEMS_EMU					PROP_TAG(PT_BOOLEAN,	PR_EC_BASE+0x0B)
+#define PR_EC_OFFLINE_PATH				PROP_TAG(PT_TSTRING,	PR_EC_BASE+0x10) /* same as PR_EC_CONTACT_ENTRYID, but on different objects! */
+#define PR_EC_OFFLINE_PATH_A			PROP_TAG(PT_STRING8,	PR_EC_BASE+0x10) /* same as PR_EC_CONTACT_ENTRYID, but on different objects! */
+#define PR_EC_OFFLINE_PATH_W			PROP_TAG(PT_UNICODE,	PR_EC_BASE+0x10) /* same as PR_EC_CONTACT_ENTRYID, but on different objects! */
 
 // Used for proxy settings
 #define PR_EC_PROXY_HOST				PROP_TAG(PT_STRING8,	PR_EC_BASE+0x0B)
@@ -108,8 +113,12 @@
 #define PR_EC_STATS_SESSION_BUSYSTATES	PROP_TAG(PT_MV_STRING8,	PR_EC_BASE+0x47)
 
 /* currently only used in user stats table */
-#define PR_EC_COMPANY_NAME				PROP_TAG(PT_STRING8,	PR_EC_BASE+0x48)
-#define PR_EC_COMPANY_ADMIN				PROP_TAG(PT_STRING8,	PR_EC_BASE+0x49)
+#define PR_EC_COMPANY_NAME				PROP_TAG(PT_TSTRING,	PR_EC_BASE+0x48)
+#define PR_EC_COMPANY_NAME_A			PROP_TAG(PT_STRING8,	PR_EC_BASE+0x48)
+#define PR_EC_COMPANY_NAME_W			PROP_TAG(PT_UNICODE,	PR_EC_BASE+0x48)
+#define PR_EC_COMPANY_ADMIN				PROP_TAG(PT_TSTRING,	PR_EC_BASE+0x49)
+#define PR_EC_COMPANY_ADMIN_A			PROP_TAG(PT_STRING8,	PR_EC_BASE+0x49)
+#define PR_EC_COMPANY_ADMIN_W			PROP_TAG(PT_UNICODE,	PR_EC_BASE+0x49)
 
 #define PR_EC_STATS_SESSION_CPU_USER	PROP_TAG(PT_DOUBLE,		PR_EC_BASE+0x4a)
 #define PR_EC_STATS_SESSION_CPU_SYSTEM	PROP_TAG(PT_DOUBLE,		PR_EC_BASE+0x4b)
@@ -122,8 +131,12 @@
 #define PR_EC_STATS_SESSION_REQUESTS	PROP_TAG(PT_LONG, 		PR_EC_BASE+0x51)
 
 #define PR_EC_OUTOFOFFICE				PROP_TAG(PT_BOOLEAN,	PR_EC_BASE+0x60)
-#define PR_EC_OUTOFOFFICE_MSG			PROP_TAG(PT_STRING8,	PR_EC_BASE+0x61)
-#define PR_EC_OUTOFOFFICE_SUBJECT		PROP_TAG(PT_STRING8, 	PR_EC_BASE+0x62)
+#define PR_EC_OUTOFOFFICE_MSG			PROP_TAG(PT_TSTRING,	PR_EC_BASE+0x61)
+#define PR_EC_OUTOFOFFICE_MSG_A			PROP_TAG(PT_STRING8,	PR_EC_BASE+0x61)
+#define PR_EC_OUTOFOFFICE_MSG_W			PROP_TAG(PT_UNICODE,	PR_EC_BASE+0x61)
+#define PR_EC_OUTOFOFFICE_SUBJECT		PROP_TAG(PT_TSTRING, 	PR_EC_BASE+0x62)
+#define PR_EC_OUTOFOFFICE_SUBJECT_A		PROP_TAG(PT_STRING8, 	PR_EC_BASE+0x62)
+#define PR_EC_OUTOFOFFICE_SUBJECT_W		PROP_TAG(PT_UNICODE, 	PR_EC_BASE+0x62)
 
 #define PR_EC_WEBACCESS_SETTINGS		PROP_TAG(PT_STRING8, PR_EC_BASE+0x70)
 #define PR_EC_RECIPIENT_HISTORY			PROP_TAG(PT_STRING8, PR_EC_BASE+0x71)
@@ -136,7 +149,9 @@
 #define PR_EC_OUTGOING_FLAGS			PROP_TAG(PT_LONG,		PR_EC_BASE+0x80)
 
 // Contains the accountname for a store (to be used from for example the outgoing queue)
-#define PR_EC_MAILBOX_OWNER_ACCOUNT		PROP_TAG(PT_STRING8,	PR_EC_BASE+0x81)
+#define PR_EC_MAILBOX_OWNER_ACCOUNT		PROP_TAG(PT_TSTRING,	PR_EC_BASE+0x81)
+#define PR_EC_MAILBOX_OWNER_ACCOUNT_A	PROP_TAG(PT_STRING8,	PR_EC_BASE+0x81)
+#define PR_EC_MAILBOX_OWNER_ACCOUNT_W	PROP_TAG(PT_UNICODE,	PR_EC_BASE+0x81)
 
 // Contains an IMAP-compatible UID for each message. It is hidden from GetPropList(), but gettable in GetProps and in tables
 // Note that we save a 64-bit counter, but the property is only 32-bit because IMAP requires it to be 32-bit.
@@ -150,12 +165,19 @@
 #define PR_EC_CLIENT_SUBMIT_DATE		PROP_TAG(PT_SYSTIME, PR_EC_BASE+0x86)
 // Stores the DATE part of an e-mail, disregarding timezone
 #define PR_EC_MESSAGE_DELIVERY_DATE		PROP_TAG(PT_SYSTIME, PR_EC_BASE+0x87)
+// Complete email for IMAP optimizations
+#define PR_EC_IMAP_EMAIL				PROP_TAG(PT_BINARY,	PR_EC_BASE+0x8C)
+#define PR_EC_IMAP_EMAIL_SIZE			PROP_TAG(PT_LONG,	PR_EC_BASE+0x8D)
+#define PR_EC_IMAP_BODY					PROP_TAG(PT_STRING8,	PR_EC_BASE+0x8E)
+#define PR_EC_IMAP_BODYSTRUCTURE		PROP_TAG(PT_STRING8,	PR_EC_BASE+0x8F)
 
 // addressbook entryids of users which are allowed to send as
 #define PR_EC_SENDAS_USER_ENTRYIDS		PROP_TAG(PT_MV_BINARY,	PR_EC_BASE+0x83)
 
 // addressbook ADS legacyExchange DN
-#define PR_EC_EXCHANGE_DN				PROP_TAG(PT_STRING8,PR_EC_BASE+0x88)
+#define PR_EC_EXCHANGE_DN				PROP_TAG(PT_TSTRING,PR_EC_BASE+0x88)
+#define PR_EC_EXCHANGE_DN_A				PROP_TAG(PT_STRING8,PR_EC_BASE+0x88)
+#define PR_EC_EXCHANGE_DN_W				PROP_TAG(PT_UNICODE,PR_EC_BASE+0x88)
 
 // notification based syncronization
 #define PR_EC_CHANGE_ADVISOR			PROP_TAG(PT_OBJECT, PR_EC_BASE+0x89)
@@ -164,8 +186,11 @@
 
 // server path to home server of a user
 #define PR_EC_SERVERPATH				PROP_TAG(PT_STRING8,	PR_EC_BASE+0xC0)
-#define PR_EC_HOMESERVER_NAME			PROP_TAG(PT_STRING8,	PR_EC_BASE+0xC1)
+#define PR_EC_HOMESERVER_NAME			PROP_TAG(PT_TSTRING,	PR_EC_BASE+0xC1)
+#define PR_EC_HOMESERVER_NAME_A			PROP_TAG(PT_STRING8,	PR_EC_BASE+0xC1)
+#define PR_EC_HOMESERVER_NAME_W			PROP_TAG(PT_UNICODE,	PR_EC_BASE+0xC1)
 #define PR_EC_SERVER_UID				PROP_TAG(PT_BINARY,		PR_EC_BASE+0xC2)
+#define PR_EC_DELETED_STORE				PROP_TAG(PT_BOOLEAN,	PR_EC_BASE+0xC3)
 
 #define PR_EC_SEARCHFOLDER_STATUS		PROP_TAG(PT_LONG,	PR_EC_BASE+0x90)
 
@@ -174,13 +199,22 @@
 #define PR_EC_AB_SYNC_STATUS			PROP_TAG(PT_BINARY,	PR_EC_BASE+0xA2)
 #define PR_EC_SYNC_WAIT_TIME			PROP_TAG(PT_LONG,	PR_EC_BASE+0xA3)
 #define PR_EC_SYNC_ON_NOTIFY			PROP_TAG(PT_LONG,	PR_EC_BASE+0xA4)
+#define PR_EC_RESYNC_ID					PROP_TAG(PT_LONG,	PR_EC_BASE+0xA5)
 
 
 // Properties for IMailUsers
 #define PR_EC_NONACTIVE					PROP_TAG(PT_BOOLEAN,	PR_EC_BASE+0xB0)
 #define PR_EC_ADMINISTRATOR				PROP_TAG(PT_LONG,		PR_EC_BASE+0xB1) // Maps to 'ulIsAdmin' in ECUser
 
-#define PR_EC_MGR_ORG_ENTRYID    		PROP_TAG(PT_BINARY,	    PR_EC_BASE+0xB2)  //this property will store original entry id of a migrated message
+#define PR_EC_MGR_ORG_ENTRYID			PROP_TAG(PT_BINARY,		PR_EC_BASE+0xB2) //this property will store original entry id of a migrated message
+#define PR_EC_ENABLED_FEATURES			PROP_TAG(PT_MV_TSTRING, PR_EC_BASE+0xB3)
+#define PR_EC_ENABLED_FEATURES_A		PROP_TAG(PT_MV_STRING8, PR_EC_BASE+0xB3)
+#define PR_EC_ENABLED_FEATURES_W		PROP_TAG(PT_MV_UNICODE, PR_EC_BASE+0xB3)
+#define PR_EC_DISABLED_FEATURES			PROP_TAG(PT_MV_TSTRING, PR_EC_BASE+0xB4)
+#define PR_EC_DISABLED_FEATURES_A		PROP_TAG(PT_MV_STRING8, PR_EC_BASE+0xB4)
+#define PR_EC_DISABLED_FEATURES_W		PROP_TAG(PT_MV_UNICODE, PR_EC_BASE+0xB4)
+
+#define PR_EC_PUBLIC_IPM_SUBTREE_ENTRYID	PROP_TAG(PT_BINARY,	PR_EC_BASE+0xD0)
 
 // Flags for PR_EC_FLAGS
 #define EC_PROFILE_FLAGS_NO_NOTIFICATIONS		0x0000001
@@ -189,6 +223,7 @@
 #define EC_PROFILE_FLAGS_OFFLINE				0x0000080
 #define EC_PROFILE_FLAGS_CACHE_PRIVATE			0x0000100
 #define EC_PROFILE_FLAGS_CACHE_PUBLIC			0x0000400
+#define EC_PROFILE_FLAGS_TRUNCATE_SOURCEKEY		0x0000800		// Truncate PR_SOURCE_KEY to 22 bytes (from 24 bytes)
 
 // Zarafa internal flags
 #define EC_PROVIDER_OFFLINE						0x0F00000
@@ -204,6 +239,22 @@
 #define ECSTORE_TYPE_PRIVATE	0
 #define ECSTORE_TYPE_PUBLIC		1
 
+// Flags for IECServiceAdmin::PurgeCache()
+#define PURGE_CACHE_QUOTA			0x0001
+#define PURGE_CACHE_QUOTADEFAULT	0x0002	
+#define PURGE_CACHE_OBJECTS			0x0004
+#define PURGE_CACHE_STORES			0x0008
+#define PURGE_CACHE_ACL				0x0010
+#define PURGE_CACHE_CELL			0x0020
+#define PURGE_CACHE_INDEX1			0x0040
+#define PURGE_CACHE_INDEX2			0x0080
+#define PURGE_CACHE_INDEXEDPROPERTIES 0x0100
+#define PURGE_CACHE_USEROBJECT		0x0200
+#define PURGE_CACHE_EXTERNID		0x0400
+#define PURGE_CACHE_USERDETAILS		0x0800
+#define PURGE_CACHE_SERVER			0x1000
+#define PURGE_CACHE_ALL				0xFFFFFFFF
+
 // Extra table flag, do not let the server cap contents on 255 characters
 // 1 bit under the MAPI_UNICODE bit, hopefully we won't clash with Exchange bits later on
 #define EC_TABLE_NOCAP			0x40000000
