@@ -53,12 +53,13 @@
 enum SCName {
 	/* server stats */
 	SCN_SERVER_STARTTIME, SCN_SERVER_LAST_CACHECLEARED, SCN_SERVER_LAST_CONFIGRELOAD,
-	SCN_SERVER_CONNECTIONS, SCN_THREAD_COUNTER, SCN_MAX_SOCKET_NUMBER, SCN_REDIRECT_COUNT,
+	SCN_SERVER_CONNECTIONS, SCN_MAX_SOCKET_NUMBER, SCN_REDIRECT_COUNT,
 	/* search folder stats */
 	SCN_SEARCHFOLDER_COUNT, SCN_SEARCHFOLDER_THREADS,
 	/* database stats */
 	SCN_DATABASE_CONNECTS, SCN_DATABASE_SELECTS, SCN_DATABASE_INSERTS, SCN_DATABASE_UPDATES, SCN_DATABASE_DELETES,
 	SCN_DATABASE_FAILED_CONNECTS, SCN_DATABASE_FAILED_SELECTS, SCN_DATABASE_FAILED_INSERTS, SCN_DATABASE_FAILED_UPDATES, SCN_DATABASE_FAILED_DELETES, SCN_DATABASE_LAST_FAILED,
+	SCN_DATABASE_MWOPS, SCN_DATABASE_MROPS, SCN_DATABASE_DEFERRED_FETCHES, SCN_DATABASE_MERGES, SCN_DATABASE_MERGED_RECORDS, SCN_DATABASE_ROW_READS, SCN_DATABASE_COUNTER_RESYNCS,
 	/* logon stats */
 	SCN_LOGIN_PASSWORD, SCN_LOGIN_SSL, SCN_LOGIN_SSO, SCN_LOGIN_SOCKET, SCN_LOGIN_DENIED,
 	/* system session stats */
@@ -67,8 +68,10 @@ enum SCName {
 	SCN_SESSIONGROUPS_CREATED, SCN_SESSIONGROUPS_DELETED,
 	/* LDAP stats */
 	SCN_LDAP_CONNECTS, SCN_LDAP_RECONNECTS, SCN_LDAP_CONNECT_FAILED, SCN_LDAP_CONNECT_TIME, SCN_LDAP_CONNECT_TIME_MAX,
-	SCN_LDAP_AUTH_LOGINS, SCN_LDAP_AUTH_DENIED, SCN_LDAP_AUTH_TIME, SCN_LDAP_AUTH_TIME_MAX,
-	SCN_LDAP_SEARCH, SCN_LDAP_SEARCH_FAILED, SCN_LDAP_SEARCH_TIME, SCN_LDAP_SEARCH_TIME_MAX
+	SCN_LDAP_AUTH_LOGINS, SCN_LDAP_AUTH_DENIED, SCN_LDAP_AUTH_TIME, SCN_LDAP_AUTH_TIME_MAX, SCN_LDAP_AUTH_TIME_AVG,
+	SCN_LDAP_SEARCH, SCN_LDAP_SEARCH_FAILED, SCN_LDAP_SEARCH_TIME, SCN_LDAP_SEARCH_TIME_MAX,
+	/* indexer stats */
+	SCN_INDEXER_SEARCH_ERRORS, SCN_INDEXER_SEARCH_MAX, SCN_INDEXER_SEARCH_AVG, SCN_INDEXED_SEARCHES, SCN_DATABASE_SEARCHES
 };
 
 
@@ -92,6 +95,10 @@ public:
 	virtual void Max(SCName name, LONGLONG max) = 0;
 	virtual void MaxTime(SCName name, time_t max) = 0;
 
+	virtual void Avg(SCName name, float add) = 0;
+	virtual void Avg(SCName name, LONGLONG add) = 0;
+	virtual void AvgTime(SCName name, time_t add) = 0;
+
 	virtual void Set(const std::string &name, const std::string &description, const std::string &value) = 0;
 	virtual void Remove(const std::string &name) = 0;
 
