@@ -89,8 +89,8 @@ public:
         unsigned int ulStartDateTime;
         unsigned int ulEndDateTime;
         unsigned int ulOriginalStartDate;
-        std::string strWideCharSubject;
-        std::string strWideCharLocation;
+        std::wstring strWideCharSubject;
+        std::wstring strWideCharLocation;
         std::string strReservedBlock2;
     };
 
