@@ -63,6 +63,9 @@ void TraceInternals(int time, char *action, char *func, char *format, ...);
 void TraceStream(int time, char *func, char *format, ...);
 void TraceECMapi(int time, char *func, char *format, ...);
 void TraceExt(int time, char *func, char *format, ...);
+void TraceRelease(char *format, ...);
+
+#define TRACE_RELEASE	TraceRelease
 
 #ifdef DEBUG
 #define TRACE_MAPI		TraceMapi
