@@ -52,9 +52,8 @@
 
 #include <utility>
 
-// _U is defined in ctype.h
-#ifdef __OpenBSD__
-#undef _U
+#ifdef free
+	#undef free
 #endif
 
 template<typename _T>
@@ -119,6 +118,13 @@ public:
 
 	
 	// Utility
+	void free() {
+		if (m_lpMemory) {
+			MAPIFreeBuffer(m_lpMemory);
+			m_lpMemory = NULL;
+		}
+	}
+
 	void swap(mapi_memory_ptr &other) {
 		std::swap(m_lpMemory, other.m_lpMemory);
 	}
@@ -130,6 +136,18 @@ public:
 	operator pointer() { return m_lpMemory; }
 	operator const_pointer() const { return m_lpMemory; }
 
+	pointer operator+(unsigned x) { return m_lpMemory + x; }
+	const_pointer operator+(unsigned x) const { return m_lpMemory + x; }
+
+	pointer get() { return m_lpMemory; }
+	const_pointer get() const { return m_lpMemory; }
+
+	pointer release() {
+		pointer lpTmp = m_lpMemory;
+		m_lpMemory = NULL;
+		return lpTmp;
+	}
+
 	operator void*() { return m_lpMemory; }
 	operator const void*() const { return m_lpMemory; }
 
@@ -142,11 +160,11 @@ public:
 		return proxy(&m_lpMemory);
 	}
 
-	template <typename _U>
-	_U as() { return (_U)m_lpMemory; }
+	template <typename _ZCPU>
+	_ZCPU as() { return (_ZCPU)m_lpMemory; }
 
-	template <typename _U>
-	const _U as() const { return (_U)m_lpMemory; }
+	template <typename _ZCPU>
+	const _ZCPU as() const { return (_ZCPU)m_lpMemory; }
 
 	operator void**() {
 		if (m_lpMemory) {
