@@ -60,10 +60,13 @@
 #include <edkguid.h>
 
 #include "IECServiceAdmin.h"
+#include "IECSecurity.h"
 #include "ECGuid.h"
 
 DEFINEMAPIPTR(ABContainer);
 DEFINEMAPIPTR(AddrBook);
+DEFINEMAPIPTR(DistList);
+DEFINEMAPIPTR(ECSecurity);
 DEFINEMAPIPTR(ECServiceAdmin);
 DEFINEMAPIPTR(ExchangeManageStore);
 DEFINEMAPIPTR(ExchangeModifyTable);
@@ -78,19 +81,22 @@ DEFINEMAPIPTR(MsgStore);
 DEFINEMAPIPTR(ProfAdmin);
 DEFINEMAPIPTR(ProfSect);
 DEFINEMAPIPTR(Unknown);
+DEFINEMAPIPTR(Stream);
 typedef mapi_object_ptr<IAttach, IID_IAttachment> AttachPtr;	// Nice... MS (not Mark S) is a bit inconsistent here.
 
 
+typedef mapi_memory_ptr<ECPERMISSION> ECPermissionPtr;
 typedef mapi_memory_ptr<ENTRYID> EntryIdPtr;
 typedef mapi_memory_ptr<ENTRYLIST> EntryListPtr;
 typedef mapi_memory_ptr<MAPIERROR> MAPIErrorPtr;
 typedef mapi_memory_ptr<ROWLIST> RowListPtr;
 typedef mapi_memory_ptr<SPropValue> SPropValuePtr;
 typedef mapi_memory_ptr<SPropTagArray> SPropTagArrayPtr;
-typedef mapi_memory_ptr<SSortOrderSet> SSortOrderSetPtr;
 typedef mapi_memory_ptr<SRestriction> SRestrictionPtr;
+typedef mapi_memory_ptr<SSortOrderSet> SSortOrderSetPtr;
+typedef mapi_memory_ptr<WCHAR> WStringPtr;
 
-
+typedef mapi_array_ptr<ECPERMISSION> ECPermissionArrayPtr;
 typedef mapi_array_ptr<SPropValue> SPropArrayPtr;
 
 
