@@ -61,11 +61,25 @@
 #define PR_ATTACH_CONTENT_ID (PROP_TAG(PT_TSTRING,0x3712))
 #endif
 
+#ifndef PR_ATTACH_CONTENT_ID_A
+#define PR_ATTACH_CONTENT_ID_A (PROP_TAG(PT_STRING8,0x3712))
+#endif
+
+#ifndef PR_ATTACH_CONTENT_ID_W
+#define PR_ATTACH_CONTENT_ID_W (PROP_TAG(PT_UNICODE,0x3712))
+#endif
+
 #ifndef PR_ATTACH_CONTENT_LOCATION
 #define PR_ATTACH_CONTENT_LOCATION (PROP_TAG(PT_TSTRING,0x3713))
 #endif
 
-#define RETURN_PROP_CASE(pt) case PROP_ID(pt): return((#pt))
+#ifndef PR_ATTACH_CONTENT_LOCATION_A
+#define PR_ATTACH_CONTENT_LOCATION_A (PROP_TAG(PT_STRING8,0x3713))
+#endif
+
+#ifndef PR_ATTACH_CONTENT_LOCATION_W
+#define PR_ATTACH_CONTENT_LOCATION_W (PROP_TAG(PT_UNICODE,0x3713))
+#endif
 
 #ifndef PR_USER_X509_CERTIFICATE
 #define PR_USER_X509_CERTIFICATE (PROP_TAG(PT_MV_BINARY,0x3a70))
@@ -84,10 +98,18 @@
 #define PR_BODY_HTML (PROP_TAG(PT_TSTRING,0x1013))
 #endif
 
-#ifndef PR_INTERNET_MESSAGE_ID 
+#ifndef PR_INTERNET_MESSAGE_ID
 #define PR_INTERNET_MESSAGE_ID PROP_TAG(PT_TSTRING, 0x1035)
 #endif
 
+#ifndef PR_INTERNET_MESSAGE_ID_A
+#define PR_INTERNET_MESSAGE_ID_A PROP_TAG(PT_STRING8, 0x1035)
+#endif
+
+#ifndef PR_INTERNET_MESSAGE_ID_W
+#define PR_INTERNET_MESSAGE_ID_W PROP_TAG(PT_UNICODE, 0x1035)
+#endif
+
 //Same as PR_INBOUND_NEWSFEED_DN
 //#ifndef PR_RULE_VERSION
 //#define PR_RULE_VERSION	PROP_TAG( PT_I2, 0x668D)
@@ -101,18 +123,38 @@
 #define PR_SMTP_ADDRESS PROP_TAG(PT_TSTRING,0x39FE)
 #endif
 
+#ifndef PR_SMTP_ADDRESS_A
+#define PR_SMTP_ADDRESS_A PROP_TAG(PT_STRING8,0x39FE)
+#endif
+
 #ifndef PR_SMTP_ADDRESS_W
 #define PR_SMTP_ADDRESS_W PROP_TAG(PT_UNICODE,0x39FE)
 #endif
 
 #ifndef	PR_DEF_POST_MSGCLASS
-#define PR_DEF_POST_MSGCLASS PROP_TAG(PT_STRING8, 0x36E5)
+#define PR_DEF_POST_MSGCLASS PROP_TAG(PT_TSTRING, 0x36E5)
+#endif
+
+#ifndef	PR_DEF_POST_MSGCLASS_A
+#define PR_DEF_POST_MSGCLASS_A PROP_TAG(PT_STRING8, 0x36E5)
+#endif
+
+#ifndef	PR_DEF_POST_MSGCLASS_W
+#define PR_DEF_POST_MSGCLASS_W PROP_TAG(PT_UNICODE, 0x36E5)
 #endif
 
 #ifndef	PR_DEF_POST_DISPLAYNAME
 #define PR_DEF_POST_DISPLAYNAME	PROP_TAG(PT_TSTRING, 0x36E6)
 #endif
 
+#ifndef	PR_DEF_POST_DISPLAYNAME_A
+#define PR_DEF_POST_DISPLAYNAME_A	PROP_TAG(PT_STRING8, 0x36E6)
+#endif
+
+#ifndef	PR_DEF_POST_DISPLAYNAME_W
+#define PR_DEF_POST_DISPLAYNAME_W	PROP_TAG(PT_UNICODE, 0x36E6)
+#endif
+
 #ifndef	PR_INTERNET_ARTICLE_NUMBER
 #define PR_INTERNET_ARTICLE_NUMBER PROP_TAG(PT_LONG, 0x0E23)
 #endif
@@ -138,10 +180,18 @@
 #define PR_RECIPIENT_ENTRYID PROP_TAG(PT_BINARY, 0x5FF7)
 #endif
 
-#ifndef	PR_RECIPIENT_DISPLAY_NAME	
+#ifndef	PR_RECIPIENT_DISPLAY_NAME
 #define PR_RECIPIENT_DISPLAY_NAME PROP_TAG(PT_TSTRING, 0x5FF6)
 #endif
 
+#ifndef	PR_RECIPIENT_DISPLAY_NAME_A
+#define PR_RECIPIENT_DISPLAY_NAME_A PROP_TAG(PT_STRING8, 0x5FF6)
+#endif
+
+#ifndef	PR_RECIPIENT_DISPLAY_NAME_W
+#define PR_RECIPIENT_DISPLAY_NAME_W PROP_TAG(PT_UNICODE, 0x5FF6)
+#endif
+
 #ifndef	PR_ICON_INDEX	
 #define PR_ICON_INDEX PROP_TAG(PT_LONG, 0x1080)
 #endif
@@ -158,10 +208,26 @@
 #define PR_FAV_DISPLAY_NAME PROP_TAG(PT_TSTRING, 0x7C00)
 #endif
 
+#ifndef	PR_FAV_DISPLAY_NAME_A
+#define PR_FAV_DISPLAY_NAME_A PROP_TAG(PT_STRING8, 0x7C00)
+#endif
+
+#ifndef	PR_FAV_DISPLAY_NAME_W
+#define PR_FAV_DISPLAY_NAME_W PROP_TAG(PT_UNICODE, 0x7C00)
+#endif
+
 #ifndef	PR_FAV_DISPLAY_ALIAS
 #define PR_FAV_DISPLAY_ALIAS PROP_TAG(PT_TSTRING, 0x7C01)
 #endif
 
+#ifndef	PR_FAV_DISPLAY_ALIAS_A
+#define PR_FAV_DISPLAY_ALIAS_A PROP_TAG(PT_STRING8, 0x7C01)
+#endif
+
+#ifndef	PR_FAV_DISPLAY_ALIAS_W
+#define PR_FAV_DISPLAY_ALIAS_W PROP_TAG(PT_UNICODE, 0x7C01)
+#endif
+
 #ifndef	PR_FAV_PUBLIC_SOURCE_KEY
 #define PR_FAV_PUBLIC_SOURCE_KEY PROP_TAG(PT_BINARY, 0x7C02)
 #endif
@@ -202,10 +268,26 @@
 #define PR_FAV_CONTAINER_CLASS PROP_TAG(PT_TSTRING, 0x7D09)
 #endif
 
+#ifndef	PR_FAV_CONTAINER_CLASS_A
+#define PR_FAV_CONTAINER_CLASS_A PROP_TAG(PT_STRING8, 0x7D09)
+#endif
+
+#ifndef	PR_FAV_CONTAINER_CLASS_W
+#define PR_FAV_CONTAINER_CLASS_W PROP_TAG(PT_UNICODE, 0x7D09)
+#endif
+
 #ifndef	PR_IN_REPLY_TO_ID
 #define PR_IN_REPLY_TO_ID PROP_TAG(PT_TSTRING, 0x1042)
 #endif
 
+#ifndef	PR_IN_REPLY_TO_ID_A
+#define PR_IN_REPLY_TO_ID_A PROP_TAG(PT_STRING8, 0x1042)
+#endif
+
+#ifndef	PR_IN_REPLY_TO_ID_W
+#define PR_IN_REPLY_TO_ID_W PROP_TAG(PT_UNICODE, 0x1042)
+#endif
+
 #ifndef PR_ATTACH_FLAGS
 #define PR_ATTACH_FLAGS PROP_TAG(PT_LONG, 0x3714)
 #endif
@@ -242,18 +324,50 @@
 #define PR_INTERNET_APPROVED PROP_TAG(PT_TSTRING,0x1030)
 #endif
 
+#ifndef PR_INTERNET_APPROVED_A
+#define PR_INTERNET_APPROVED_A PROP_TAG(PT_STRING8,0x1030)
+#endif
+
+#ifndef PR_INTERNET_APPROVED_W
+#define PR_INTERNET_APPROVED_W PROP_TAG(PT_UNICODE,0x1030)
+#endif
+
 #ifndef PR_INTERNET_CONTROL
 #define PR_INTERNET_CONTROL PROP_TAG(PT_TSTRING,0x1031)
 #endif
 
+#ifndef PR_INTERNET_CONTROL_A
+#define PR_INTERNET_CONTROL_A PROP_TAG(PT_STRING8,0x1031)
+#endif
+
+#ifndef PR_INTERNET_CONTROL_W
+#define PR_INTERNET_CONTROL_W PROP_TAG(PT_UNICODE,0x1031)
+#endif
+
 #ifndef PR_INTERNET_DISTRIBUTION
 #define PR_INTERNET_DISTRIBUTION PROP_TAG(PT_TSTRING,0x1032)
 #endif
 
+#ifndef PR_INTERNET_DISTRIBUTION_A
+#define PR_INTERNET_DISTRIBUTION_A PROP_TAG(PT_STRING8,0x1032)
+#endif
+
+#ifndef PR_INTERNET_DISTRIBUTION_W
+#define PR_INTERNET_DISTRIBUTION_W PROP_TAG(PT_UNICODE,0x1032)
+#endif
+
 #ifndef PR_INTERNET_FOLLOWUP_TO
 #define PR_INTERNET_FOLLOWUP_TO PROP_TAG(PT_TSTRING,0x1033)
 #endif
 
+#ifndef PR_INTERNET_FOLLOWUP_TO_A
+#define PR_INTERNET_FOLLOWUP_TO_A PROP_TAG(PT_STRING8,0x1033)
+#endif
+
+#ifndef PR_INTERNET_FOLLOWUP_TO_W
+#define PR_INTERNET_FOLLOWUP_TO_W PROP_TAG(PT_UNICODE,0x1033)
+#endif
+
 #ifndef PR_INTERNET_LINES
 #define PR_INTERNET_LINES PROP_TAG(PT_LONG,0x1034)
 #endif
@@ -262,23 +376,63 @@
 #define PR_INTERNET_NEWSGROUPS PROP_TAG(PT_TSTRING,0x1036)
 #endif
 
+#ifndef PR_INTERNET_NEWSGROUPS_A
+#define PR_INTERNET_NEWSGROUPS_A PROP_TAG(PT_STRING8,0x1036)
+#endif
+
+#ifndef PR_INTERNET_NEWSGROUPS_W
+#define PR_INTERNET_NEWSGROUPS_W PROP_TAG(PT_UNICODE,0x1036)
+#endif
+
 #ifndef PR_INTERNET_NNTP_PATH
 #define PR_INTERNET_NNTP_PATH PROP_TAG(PT_TSTRING,0x1038)
 #endif
 
+#ifndef PR_INTERNET_NNTP_PATH_A
+#define PR_INTERNET_NNTP_PATH_A PROP_TAG(PT_STRING8,0x1038)
+#endif
+
+#ifndef PR_INTERNET_NNTP_PATH_W
+#define PR_INTERNET_NNTP_PATH_W PROP_TAG(PT_UNICODE,0x1038)
+#endif
+
 #ifndef PR_INTERNET_ORGANIZATION
 #define PR_INTERNET_ORGANIZATION PROP_TAG(PT_TSTRING,0x1037)
 #endif
 
+#ifndef PR_INTERNET_ORGANIZATION_A
+#define PR_INTERNET_ORGANIZATION_A PROP_TAG(PT_STRING8,0x1037)
+#endif
+
+#ifndef PR_INTERNET_ORGANIZATION_W
+#define PR_INTERNET_ORGANIZATION_W PROP_TAG(PT_UNICODE,0x1037)
+#endif
+
 #ifndef PR_INTERNET_PRECEDENCE
 #define PR_INTERNET_PRECEDENCE PROP_TAG(PT_TSTRING,0x1041)
 #endif
 
+#ifndef PR_INTERNET_PRECEDENCE_A
+#define PR_INTERNET_PRECEDENCE_A PROP_TAG(PT_STRING8,0x1041)
+#endif
+
+#ifndef PR_INTERNET_PRECEDENCE_W
+#define PR_INTERNET_PRECEDENCE_W PROP_TAG(PT_UNICODE,0x1041)
+#endif
+
 #ifndef PR_INTERNET_REFERENCES
 #define PR_INTERNET_REFERENCES PROP_TAG(PT_TSTRING,0x1039)
 #endif
 
-#ifndef PR_NEWSGROUP_NAME
+#ifndef PR_INTERNET_REFERENCES_A
+#define PR_INTERNET_REFERENCES_A PROP_TAG(PT_STRING8,0x1039)
+#endif
+
+#ifndef PR_INTERNET_REFERENCES_W
+#define PR_INTERNET_REFERENCES_W PROP_TAG(PT_UNICODE,0x1039)
+#endif
+
+#ifndef UNICODE_NEWSGROUP_NAME
 #define PR_NEWSGROUP_NAME PROP_TAG(PT_TSTRING,0x0E24)
 #endif
 
@@ -286,6 +440,14 @@
 #define PR_NNTP_XREF PROP_TAG(PT_TSTRING,0x1040)
 #endif
 
+#ifndef PR_NNTP_XREF_A
+#define PR_NNTP_XREF_A PROP_TAG(PT_STRING8,0x1040)
+#endif
+
+#ifndef PR_NNTP_XREF_W
+#define PR_NNTP_XREF_W PROP_TAG(PT_UNICODE,0x1040)
+#endif
+
 #ifndef PR_POST_FOLDER_ENTRIES
 #define PR_POST_FOLDER_ENTRIES PROP_TAG(PT_BINARY,0x103B)
 #endif
@@ -294,6 +456,14 @@
 #define PR_POST_FOLDER_NAMES PROP_TAG(PT_TSTRING,0x103C)
 #endif
 
+#ifndef PR_POST_FOLDER_NAMES_A
+#define PR_POST_FOLDER_NAMES_A PROP_TAG(PT_STRING8,0x103C)
+#endif
+
+#ifndef PR_POST_FOLDER_NAMES_W
+#define PR_POST_FOLDER_NAMES_W PROP_TAG(PT_UNICODE,0x103C)
+#endif
+
 #ifndef PR_POST_REPLY_FOLDER_ENTRIES
 #define PR_POST_REPLY_DENIED PROP_TAG(PT_BINARY,0x103F)
 #endif
@@ -306,10 +476,30 @@
 #define PR_POST_REPLY_FOLDER_NAMES PROP_TAG(PT_TSTRING,0x103E)
 #endif
 
+#ifndef PR_POST_REPLY_FOLDER_NAMES_A
+#define PR_POST_REPLY_FOLDER_NAMES_A PROP_TAG(PT_STRING8,0x103E)
+#endif
+
+#ifndef PR_POST_REPLY_FOLDER_NAMES_W
+#define PR_POST_REPLY_FOLDER_NAMES_W PROP_TAG(PT_UNICODE,0x103E)
+#endif
+
 #ifndef PR_SUPERSEDES
 #define PR_SUPERSEDES PROP_TAG(PT_TSTRING,0x103A)
 #endif
 
+#ifndef PR_SUPERSEDES_A
+#define PR_SUPERSEDES_A PROP_TAG(PT_STRING8,0x103A)
+#endif
+
+#ifndef PR_SUPERSEDES_W
+#define PR_SUPERSEDES_W PROP_TAG(PT_UNICODE,0x103A)
+#endif
+
+#ifndef PR_7BIT_DISPLAY_NAME_W
+#define PR_7BIT_DISPLAY_NAME_W PROP_TAG(PT_UNICODE, PROP_ID(PR_7BIT_DISPLAY_NAME))
+#endif
+
 #define PR_PACKED_NAME_PROPS		PROP_TAG(PT_BINARY, 0x361C)
 
 #define PR_IPM_APPOINTMENT_ENTRYID	PROP_TAG(PT_BINARY, 0x36D0)
@@ -513,7 +703,7 @@ PR_ADDITIONAL_REN_ENTRYIDS:
 
 /* delegate properties */
 /* from exchange private range? */
-#define PR_SCHDINFO_DELEGATE_NAMES			PROP_TAG(PT_MV_STRING8, 0x6844)
+#define PR_SCHDINFO_DELEGATE_NAMES			PROP_TAG(PT_MV_TSTRING, 0x6844)
 #define PR_SCHDINFO_DELEGATE_ENTRYIDS		PROP_TAG(PT_MV_BINARY, 0x6845)
 #define PR_DELEGATE_FLAGS					PROP_TAG(PT_MV_LONG, 0x686B)
 
@@ -587,4 +777,25 @@ PR_ADDITIONAL_REN_ENTRYIDS:
 #define AB_RESERVED1	0x00000100
 #define AB_LOCK_NON_ACL	0x00000200
 
+#define PR_ASSOCIATED_SHARING_PROVIDER			PROP_TAG(PT_CLSID, 0x0ea0)
+#define PR_EMSMDB_SECTION_UID					PROP_TAG(PT_BINARY, 0x3d15)
+#define PR_EMSMDB_LEGACY						PROP_TAG(PT_BOOLEAN, 0x3D18)
+#define PR_EMSABP_USER_UID						PROP_TAG(PT_BINARY, 0x3D1A)
+
+#define PR_ARCHIVE_TAG			PROP_TAG(PT_BINARY, 0x3018)
+#define PR_ARCHIVE_PERIOD		PROP_TAG(PT_LONG, 0x301e)
+#define PR_ARCHIVE_DATE			PROP_TAG(PT_SYSTIME, 0x301f)
+#define PR_RETENTION_FLAGS		PROP_TAG(PT_LONG, 0x301d)
+#define PR_RETENTION_DATE		PROP_TAG(PT_SYSTIME, 0x301c)
+#define PR_POLICY_TAG			PROP_TAG(PT_BINARY, 0x3019)
+#define PR_ROAMING_DATATYPES	PROP_TAG(PT_LONG, 0x7c06)
+
+#define PR_ITEM_TMPFLAGS		PROP_TAG(PT_LONG, 0x1097)
+#define PR_SECURE_SUBMIT_FLAGS	PROP_TAG(PT_LONG, 0x65C6)
+#define PR_SECURITY_FLAGS		PROP_TAG(PT_LONG, 0x6E01)
+
+#define PR_CONVERSATION_ID		PROP_TAG(PT_BINARY, 0x3013)
+
+#define PR_AB_CHOOSE_DIRECTORY_AUTOMATICALLY PROP_TAG( PT_BOOLEAN, 0x3D1C)
+
 #endif
