@@ -163,6 +163,8 @@
 #define dispidApptCounterProposal			0x8257	//PT_BOOLEAN
 #define dispidApptReplyTime					0x8220	//PT_SYSTIME
 
+#define dispidOrgMsgId						0x8251  //PT_BINARY
+
 // New in OLK 2007
 #define dispidApptTZDefStartDisplay			0x825E
 #define dispidApptTZDefEndDisplay			0x825F
@@ -238,5 +240,62 @@
 #define dispidLogDuration					0x8707
 #define dispidLogEnd						0x8708
 
-#endif
 
+// Values for dispidSideEffect, from [MS-OXCMSG].pdf, par 2.2.1.1.6
+// Additional processing is required on the Message object when deleting.
+#define seOpenToDelete		0x0001
+// No UI is associated with the Message object.
+#define seNoFrame			0x0008
+// Additional processing is required on the Message object when moving
+// or copying to a Folder object with a PidTagContainerClass of
+// "IPF.Note". For more details about the PidTagContainerClass property,
+// see [MS-OXOSFLD] section 2.2.5.
+#define seCoerceToInbox		0x0010
+// Additional processing is required on the Message object when
+// copying to another folder.
+#define seOpenToCopy		0x0020
+// Additional processing is required on the Message object when moving
+// to another folder.
+#define seOpenToMove		0x0040
+// Additional processing is required on the Message object when
+// displaying verbs to the end-user.
+#define seOpenForCtxMenu	0x0100
+// Cannot undo delete operation, MUST NOT be set unless "0x0001" is set.
+#define seCannotUndoDelete	0x0400
+// Cannot undo copy operation, MUST NOT be set unless "0x0020" is set.
+#define seCannotUndoCopy	0x0800
+// Cannot undo move operation, MUST NOT be set unless "0x0040" is set.
+#define seCannotUndoMove	0x1000
+// The Message object contains end-user script.
+#define seHasScript			0x2000
+// Additional processing is required to permanently delete the Message object.
+#define seOpenToPermDelete	0x4000
+
+
+/**
+ * Values for PidLidResponseStatus
+ */
+// No response is required for this object. This is the case for
+// Appointment objects and Meeting Response objects.
+#define respNone		0x00000000
+// This Meeting object belongs to the organizer.
+#define respOrganized	0x00000001
+// This value on the attendee's Meeting object indicates that the
+// attendee has tentatively accepted the Meeting Request object.
+#define respTentative	0x00000002
+// This value on the attendee's Meeting object indicates that the
+// attendee has accepted the Meeting Request object.
+#define respAccepted	0x00000003
+// This value on the attendee's Meeting object indicates that the
+// attendee has declined the Meeting Request object.
+#define respDeclined	0x00000004
+// This value on the attendee's Meeting object indicates that the
+// attendee has not yet responded. This value is on the Meeting Request
+// object, Meeting Update object, and Meeting Cancellation object.
+#define respNotResponded 0x00000005
+
+
+/* PS_EC_IMAP named PropTags */
+#define dispidIMAPEnvelope		0x0001
+
+#endif
