@@ -56,13 +56,11 @@
 #if OPENBSD
   #include <sys/types.h>
   #include <sys/select.h>
-  #undef __FD_SETSIZE
-  #define __FD_SETSIZE FD_SETSIZE
 #else
   #include <bits/types.h>
+#endif
   #undef __FD_SETSIZE
   #define __FD_SETSIZE 8192
-#endif
 
   // Log the pthreads locks
   #define DEBUG_PTHREADS 0
@@ -70,7 +68,8 @@
   #include <config.h>
   #include "platform.linux.h"
 
-#define ZARAFA_SYSTEM_USER	"SYSTEM"
+#define ZARAFA_SYSTEM_USER		"SYSTEM"
+#define ZARAFA_SYSTEM_USER_W	L"SYSTEM"
 
 static const LONGLONG UnitsPerMinute = 600000000;
 static const LONGLONG UnitsPerHalfMinute = 300000000;
