@@ -87,11 +87,10 @@
   #include <uuid.h>
 #endif
 
-
-#ifndef DEBUG
-  /* make assert() generate no code */
-  #define NDEBUG
+#ifndef UNUSED_VAR
+#define UNUSED_VAR __attribute__((unused))
 #endif
+
 #include <assert.h>
 /* windows compatible asserts ? */
 #define ASSERT assert
@@ -168,7 +167,7 @@ typedef __int64_t __int64;
 
 /* find parent class */
 #define METHOD_PROLOGUE_(theClass, localClass) \
-	theClass* pThis = \
+	UNUSED_VAR theClass* pThis = \
 		((theClass*)((BYTE*)this - offsetof1(theClass, m_x##localClass)));
 
 /* GUID defines */
@@ -179,6 +178,7 @@ typedef struct __attribute__((__packed__)) _s_GUID {
     BYTE	Data4[8];
 } GUID;
 typedef GUID*  LPGUID;
+typedef const GUID *LPCGUID;
 
 typedef GUID   IID;
 typedef IID*   LPIID;
@@ -345,14 +345,14 @@ typedef unsigned int*	LPLHANDLE;
 
 
 /* mapidefs.h (and more) types */
-typedef unsigned short 	WCHAR;
+typedef wchar_t 	WCHAR;
 
 #ifdef UNICODE
   typedef WCHAR		TCHAR;
-  #define _T(x) L##x
+#define _T(x) L##x
 #else
   typedef char		TCHAR;
-  #define _T(x) x
+#define _T(x) x
 #endif
 typedef unsigned char	TBYTE;
 
@@ -362,15 +362,6 @@ typedef TCHAR*			LPTSTR;
 typedef const TCHAR*	LPCTSTR;
 typedef WCHAR			OLECHAR;
 
-// used in Zarafa.h
-#ifdef UNICODE
-  #define lstrlen wcslen
-  #define lstrcpy wcscpy
-#else
-  #define lstrlen strlen
-  #define lstrcpy strcpy
-#endif
-
 typedef struct _s_FILETIME {
     DWORD dwLowDateTime;
     DWORD dwHighDateTime;
@@ -617,29 +608,39 @@ __int64_t Int32x32To64(ULONG, ULONG);
 
 void GetSystemTimeAsFileTime(FILETIME *ft);
 DWORD GetTempPath(DWORD inLen, char *lpBuffer);
-int mbstounicode(WCHAR *dest, const char *src, size_t n); 
-int unicodetombs(char *dest, const WCHAR *src, size_t n);
-int unicodelen(WCHAR *src);
-int unicodecmp(WCHAR *str1, WCHAR *str2);
-void unicodecpy(WCHAR *dest, WCHAR *src);
+#define GetTempPathA GetTempPath
+
+#define utf32len wcslen
 
 /* Some wrappers to map Windows unicode functions */
 static inline int lstrcmpW(LPCWSTR str1, LPCWSTR str2)
 {
-	return unicodecmp((WCHAR *)str1, (WCHAR *)str2);
+	return wcscmp((WCHAR *)str1, (WCHAR *)str2);
 }
 
 static inline int lstrlenW(LPCWSTR str)
 {
-	return unicodelen((WCHAR *)str);
+	return wcslen((WCHAR *)str);
 }
 
 static inline LPWSTR lstrcpyW(LPWSTR dst, LPCWSTR src)
 {
-	unicodecpy(dst, (WCHAR *)src);
+	wcscpy(dst, (WCHAR *)src);
 	return dst;
 }
 
+#ifdef UNICODE
+#define _tcslen	wcslen
+#define _tcscpy wcscpy
+#define _tcscmp wcscmp
+#define _tcsicmp wcscasecmp
+#else
+#define _tcslen strlen
+#define _tcscpy strcpy
+#define _tcscmp strcmp
+#define _tcsicmp stricmp
+#endif
+
 void Sleep(unsigned int usec);
 
 /* because the flags are not used linux, they do not match the windows flags! */
@@ -691,8 +692,8 @@ time_t GetProcessTime();
 	#endif
 #endif
 
-#define OutputDebugString(dstr) fprintf(stderr,"%s",dstr)
-#define GetCurrentThreadId() (long)pthread_self()
+#define OutputDebugStringA(dstr) fprintf(stderr,"%s",dstr)
+#define GetCurrentThreadId() (intptr_t)pthread_self()
 #define GetTickCount() 0L
 
 #define TICKS_PER_SEC (sysconf(_SC_CLK_TCK))
@@ -711,8 +712,9 @@ time_t GetProcessTime();
 #endif
 
 
-
+#define localemask(_cat) (_cat ## _MASK)
 #define createlocale(_cat, _loc) newlocale(_cat ## _MASK, _loc, NULL)
+#define createlocale_real(_cat, _loc) newlocale(_cat, _loc, NULL)
 
 /**
  * Tell the compiler that a funtion/method behaves like printf.
