@@ -64,6 +64,13 @@ struct stricmp_comparison {
 	}
 };
 
+struct wcscasecmp_comparison {
+	bool operator()(const std::wstring &left, const std::wstring &right) const
+	{
+		return ((left.size() < right.size()) || ((left.size() == right.size()) && (wcscasecmp(left.c_str(), right.c_str()) < 0)));
+	}
+};
+
 static inline std::string strToUpper(std::string f) {
 	transform(f.begin(), f.end(), f.begin(), ::toupper);
 	return f;
@@ -74,22 +81,33 @@ static inline std::string strToLower(std::string f) {
 	return f;
 }
 
-std::wstring towstring(const std::string &s);
-std::string tostring(const std::wstring &ws);
-
 // Use casting if passing hard coded values.
 std::string stringify(unsigned int x, bool usehex = false, bool _signed = false);
 std::string stringify_int64(long long x, bool usehex = false);
 std::string stringify_float(float x);
-std::string stringify_double(double x, int prec = 18);
+std::string stringify_double(double x, int prec = 18, bool bLocale = false);
 std::string stringify_datetime(time_t x);
 
-std::wstring wstringify(unsigned int x, bool usehex = false);
+std::wstring wstringify(unsigned int x, bool usehex = false, bool _signed = false);
 std::wstring wstringify_int64(long long x, bool usehex = false);
 std::wstring wstringify_uint64(unsigned long long x, bool usehex = false);
 std::wstring wstringify_float(float x);
 std::wstring wstringify_double(double x, int prec = 18);
 
+#ifdef UNICODE
+	#define tstringify			wstringify
+	#define tstringify_int64	wstringify_int64
+	#define tstringify_uint64	wstringify_uint64
+	#define tstringify_float	wstringify_float
+	#define tstringify_double	wstringify_double
+#else
+	#define tstringify			stringify
+	#define tstringify_int64	stringify_int64
+	#define tstringify_uint64	stringify_uint64
+	#define tstringify_float	stringify_float
+	#define tstringify_double	stringify_double
+#endif
+
 inline unsigned int	atoui(const char *szString) { return strtoul(szString, NULL, 10); }
 unsigned int xtoi(const char *lpszHex);
 
@@ -109,10 +127,10 @@ static inline bool parseBool(const std::string &s) {
 	return !(s == "0" || s == "false" || s == "no");
 }
 
-void strMakeUnicode(const char *lpszA, WCHAR **lpszW);
-
 std::string shell_escape(std::string str);
+std::string shell_escape(std::wstring wstr);
 
+std::vector<std::wstring> tokenize(const std::wstring &strInput, const WCHAR sep);
 std::vector<std::string> tokenize(const std::string &strInput, const char sep);
 std::string concatenate(std::vector<std::string> &elements, const std::string &delimeters);
 
@@ -120,7 +138,15 @@ std::string trim(const std::string &strInput, const std::string &strTrim = " ");
 
 unsigned char x2b(char c);
 std::string hex2bin(const std::string &input);
+std::string hex2bin(const std::wstring &input);
+
 std::string bin2hex(unsigned int inLength, const unsigned char *input);
+std::wstring bin2hexw(unsigned int inLength, const unsigned char *input);
+#ifdef UNICODE
+#define bin2hext bin2hexw
+#else
+#define bin2hext bin2hex
+#endif
 
 std::string StringEscape(const char* input, const char *tokens, const char escape);
 
@@ -164,4 +190,16 @@ std::vector<std::basic_string<T> > tokenize(const T* str, const T* delimiters)
 	return tokenize(std::basic_string<T>(str), std::basic_string<T>(delimiters));
 }
 
+template<typename _InputIterator, typename _Tp>
+_Tp join(_InputIterator __first, _InputIterator __last, _Tp __sep)
+{
+    _Tp s;
+    for (; __first != __last; ++__first) {
+        if(!s.empty())
+            s += __sep;
+        s += *__first;
+    }
+    return s;
+}
+
 #endif
