@@ -1,7 +1,8 @@
 # shell include script
 
-ZARAFA_LANG="${LC_MESSAGES:-en_EN}"
+ZARAFA_LANG="${ZARAFA_USERSCRIPT_LOCALE:-${LC_MESSAGES:-en_US}}"
 PATH=$PATH:/usr/local/bin
+export ZARAFA_LANG PATH
 
 if [ -z "${ZARAFA_USER_SCRIPTS}" ] ; then
     exec >&2
